(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='WolframDesktop 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       161,          7]
NotebookDataLength[    101246,       2295]
NotebookOptionsPosition[     86859,       2054]
NotebookOutlinePosition[     87254,       2070]
CellTagsIndexPosition[     87211,       2067]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Computational Poetry Adventure", "Title",
 CellChangeTimes->{{3.899476141225541*^9, 3.899476145176695*^9}, {
  3.902335123684823*^9, 
  3.902335125022238*^9}},ExpressionUUID->"3894caf4-5037-4ed6-b57a-\
c15f855cc6b6"],

Cell[CellGroupData[{

Cell["Manipulating Strings in Wolfram Language", "Section",
 CellChangeTimes->{{3.8994761755435658`*^9, 
  3.899476195230053*^9}},ExpressionUUID->"3ad9457c-e5b3-4a8e-bdee-\
f29ff6b4d8b2"],

Cell[CellGroupData[{

Cell["How Wolfram Language deals with words", "Subsection",
 CellChangeTimes->{{3.899476198387776*^9, 
  3.899476231668153*^9}},ExpressionUUID->"37c50f37-a104-4ba5-bfea-\
21ce7e6687d7"],

Cell["\<\
There are lots of different ways to get words in Wolfram Language. We can \
look at the dictionary, which gives us almost 40,000 words in English:\
\>", "Text",
 CellChangeTimes->{{3.899476226476548*^9, 3.899476254091297*^9}, {
  3.899476295487105*^9, 
  3.8994762993212633`*^9}},ExpressionUUID->"0b38ea4f-3b27-49d3-9162-\
7098af5102d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WordList", "[", "]"}]], "Input",
 CellChangeTimes->{{3.8994762558045683`*^9, 3.899476285362558*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"ac5a44be-5570-4ad4-aca8-dfde52ebb472"],

Cell[BoxData[
 TemplateBox[<|"shortenedBoxes" -> TagBox[
     RowBox[{"{", 
       RowBox[{
        "\"a\"", ",", "\"aah\"", ",", "\"aardvark\"", ",", "\"aback\"", ",", 
         "\"abacus\"", ",", "\"abaft\"", ",", "\"abalone\"", ",", 
         "\"abandon\"", ",", "\"abandoned\"", ",", "\"abandonment\"", ",", 
         "\"abase\"", ",", "\"abasement\"", ",", "\"abash\"", ",", 
         "\"abashed\"", ",", "\"abashment\"", ",", "\"abate\"", ",", 
         "\"abatement\"", ",", "\"abattoir\"", ",", "\"abbe\"", ",", 
         "\"abbess\"", ",", "\"abbey\"", ",", "\"abbot\"", ",", 
         "\"abbreviate\"", ",", "\"abbreviated\"", ",", "\"abbreviation\"", 
         ",", "\"abdicate\"", ",", "\"abdication\"", ",", 
         TemplateBox[{"39122"}, "OutputSizeLimit`Skeleton"], ",", 
         "\"zinnia\"", ",", "\"zip\"", ",", "\"zipper\"", ",", "\"zippy\"", 
         ",", "\"zircon\"", ",", "\"zirconium\"", ",", "\"zit\"", ",", 
         "\"zither\"", ",", "\"zloty\"", ",", "\"zodiac\"", ",", 
         "\"zodiacal\"", ",", "\"zombie\"", ",", "\"zonal\"", ",", "\"zone\"",
          ",", "\"zoning\"", ",", "\"zoo\"", ",", "\"zoological\"", ",", 
         "\"zoologist\"", ",", "\"zoology\"", ",", "\"zoom\"", ",", 
         "\"zoophyte\"", ",", "\"zounds\"", ",", "\"zucchini\"", ",", 
         "\"zwieback\"", ",", "\"zydeco\"", ",", "\"zygote\"", ",", 
         "\"zygotic\""}], "}"}], Short[#, 8]& ], "line" -> 114, "sessionID" -> 
   30410024793730115014, "byteCount" -> 1756680, "size" -> 8, "stored" -> 
   False, "expr" -> Missing["NotAvailable", "NewSessionID"], "wrap" -> 
   OutputSizeLimit`Defer, "version" -> 1|>,
  "OutputSizeLimitTemplate"]], "Output",
 CellChangeTimes->{{3.89947626101155*^9, 3.8994762859899693`*^9}},
 CellLabel->
  "Out[114]=",ExpressionUUID->"dbb92afd-c5c9-46f1-80f8-1fcbc5c9d468"]
}, Open  ]],

Cell["We can also generate a random word:", "Text",
 CellChangeTimes->{{3.8994762635312366`*^9, 
  3.899476319255918*^9}},ExpressionUUID->"474bb9d5-e07b-4cc9-b633-\
a2421ecbc498"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomWord", "[", "]"}]], "Input",
 CellChangeTimes->{{3.899476320280493*^9, 3.899476322770355*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"20ca7e72-a2d2-4b42-b4fe-104c43e590a4"],

Cell[BoxData["\<\"lengthen\"\>"], "Output",
 CellChangeTimes->{3.899476323558312*^9, 3.899476364753543*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"df705068-dc89-4531-b77a-e2c0db8ebaa7"]
}, Open  ]],

Cell["\<\
For RandomWord, we can specify if we want a noun, verb, adjective, or another \
type of word:\
\>", "Text",
 CellChangeTimes->{{3.89947632651266*^9, 
  3.899476347534255*^9}},ExpressionUUID->"1e6ff15a-f850-4b41-bfd7-\
5866ba9026b5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomWord", "[", "\"\<Verb\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.899476348639134*^9, 3.8994763588621407`*^9}},
 CellLabel->
  "In[117]:=",ExpressionUUID->"eda8f463-7509-444b-a3cf-d5bcccc5d5e1"],

Cell[BoxData["\<\"conclude\"\>"], "Output",
 CellChangeTimes->{{3.89947635477363*^9, 3.899476359857106*^9}},
 CellLabel->
  "Out[117]=",ExpressionUUID->"a3022ccc-c722-4960-996e-4fb0fd9cb7fa"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Joining and Splitting strings", "Subsection",
 CellChangeTimes->{{3.899476385124652*^9, 
  3.899476393928941*^9}},ExpressionUUID->"3aa90122-6986-4f43-be27-\
9d2e62182298"],

Cell["All text in Wolfram Language is a string:", "Text",
 CellChangeTimes->{{3.899476396353059*^9, 
  3.899476415267234*^9}},ExpressionUUID->"d1f2f584-b883-4a17-84e6-\
9b468e1fa353"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "\"\<hello!\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.899476405813678*^9, 3.8994764088603983`*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"d860fb2b-5a19-459b-ba64-d7d6c19dcb3b"],

Cell[BoxData["String"], "Output",
 CellChangeTimes->{3.8994764093785057`*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"5cafa0a4-4701-45f3-be21-e01f41555496"]
}, Open  ]],

Cell["We make strings with quotation marks (\[OpenCurlyDoubleQuote]\
\[CloseCurlyDoubleQuote]):", "Text",
 CellChangeTimes->{{3.899476418230936*^9, 3.899476423018346*^9}, {
  3.90233115175733*^9, 
  3.9023311605375843`*^9}},ExpressionUUID->"6c0ebe9e-7002-4d24-bb62-\
365104d4c1df"],

Cell[CellGroupData[{

Cell[BoxData["\"\<hello!\>\""], "Input",
 CellChangeTimes->{{3.8994764244852123`*^9, 3.899476433005281*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"9f45b3a0-5958-4a53-ac6f-c4a47c27852b"],

Cell[BoxData["\<\"hello!\"\>"], "Output",
 CellChangeTimes->{{3.8994764261876307`*^9, 3.899476433997858*^9}},
 CellLabel->
  "Out[121]=",ExpressionUUID->"06f3165d-65b5-4087-823a-19f357a9dd91"]
}, Open  ]],

Cell["\<\
If we have multiple words in a string, we can separate them using \
StringSplit, which automatically splits the string at each space.\
\>", "Text",
 CellChangeTimes->{{3.8994764441216507`*^9, 3.8994764833197107`*^9}, 
   3.902331181384007*^9},ExpressionUUID->"2de434a6-c61a-4f30-a504-\
0831707455c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", "\"\<hello world I am learning Wolfram\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.899476484329359*^9, 3.8994765037296457`*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"8c868894-921e-4bf6-95f1-2c0e506a119d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"hello\"\>", ",", "\<\"world\"\>", ",", "\<\"I\"\>", 
   ",", "\<\"am\"\>", ",", "\<\"learning\"\>", ",", "\<\"Wolfram\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.899476500006901*^9, 3.89947650487017*^9}},
 CellLabel->
  "Out[123]=",ExpressionUUID->"11ad3af2-a0b3-43ff-b801-19d300810dd6"]
}, Open  ]],

Cell["\<\
If we want to join a list of strings into one string, we can do that with \
StringJoin:\
\>", "Text",
 CellChangeTimes->{{3.899476513654581*^9, 
  3.899476528984797*^9}},ExpressionUUID->"123a88f0-549a-43b0-ac9b-\
8cf36e8b3e1f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringJoin", "[", 
  RowBox[{"{", 
   RowBox[{
   "\"\<hello\>\"", ",", "\"\<world\>\"", ",", "\"\<I\>\"", ",", "\"\<am\>\"",
     ",", "\"\<learning\>\"", ",", "\"\<Wolfram\>\""}], "}"}], "]"}]], "Input",\

 CellChangeTimes->{{3.899476530141869*^9, 3.899476537251705*^9}},
 CellLabel->
  "In[124]:=",ExpressionUUID->"fb43c1e9-817d-4a7f-baca-7d9b91eb9ebe"],

Cell[BoxData["\<\"helloworldIamlearningWolfram\"\>"], "Output",
 CellChangeTimes->{3.899476538328096*^9},
 CellLabel->
  "Out[124]=",ExpressionUUID->"cabefd4e-45a1-49fb-b6d6-eba3b2aa91cb"]
}, Open  ]],

Cell["\<\
That looks a little weird since we lost the spaces. A way we can get them \
back is by using a function called Riffle, which puts something in between \
every item in a list:\
\>", "Text",
 CellChangeTimes->{{3.899476540541575*^9, 3.8994765783384647`*^9}, {
  3.9023312088033733`*^9, 
  3.9023312105556393`*^9}},ExpressionUUID->"3fbf4bbc-49ce-452f-9af2-\
b5ae7915fd53"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Riffle", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<hello\>\"", ",", "\"\<world\>\"", ",", "\"\<I\>\"", ",", 
     "\"\<am\>\"", ",", "\"\<learning\>\"", ",", "\"\<Wolfram\>\""}], "}"}], 
   ",", "\"\< \>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.899476579480667*^9, 3.899476586394335*^9}},
 CellLabel->
  "In[125]:=",ExpressionUUID->"a10c94fe-f5fb-4019-ad71-a28cd8604b07"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"hello\"\>", ",", "\<\" \"\>", ",", "\<\"world\"\>", 
   ",", "\<\" \"\>", ",", "\<\"I\"\>", ",", "\<\" \"\>", ",", "\<\"am\"\>", 
   ",", "\<\" \"\>", ",", "\<\"learning\"\>", ",", "\<\" \"\>", 
   ",", "\<\"Wolfram\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.899476586927882*^9},
 CellLabel->
  "Out[125]=",ExpressionUUID->"856859f4-a1a8-475c-82db-38eb56ed2f72"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringJoin", "[", 
  RowBox[{"{", 
   RowBox[{
   "\"\<hello\>\"", ",", "\"\< \>\"", ",", "\"\<world\>\"", ",", "\"\< \>\"", 
    ",", "\"\<I\>\"", ",", "\"\< \>\"", ",", "\"\<am\>\"", ",", "\"\< \>\"", 
    ",", "\"\<learning\>\"", ",", "\"\< \>\"", ",", "\"\<Wolfram\>\""}], 
   "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.899476589885352*^9, 3.89947659636731*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"a6db4580-72cc-4f3f-bf81-51ea6ed4853f"],

Cell[BoxData["\<\"hello world I am learning Wolfram\"\>"], "Output",
 CellChangeTimes->{3.899476597267612*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"06c7329f-5ffa-411b-9dd4-810d2e74b01f"]
}, Open  ]],

Cell["\<\
Of course, we don\[CloseCurlyQuote]t have to do this in two different lines \
of code:\
\>", "Text",
 CellChangeTimes->{{3.899476600825656*^9, 3.8994766071933193`*^9}, {
  3.899477174616776*^9, 
  3.899477182379833*^9}},ExpressionUUID->"3174a657-809b-444a-9bb1-\
ad21cf13192a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringJoin", "[", 
  RowBox[{"Riffle", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\"\<hello\>\"", ",", "\"\<world\>\"", ",", "\"\<I\>\"", ",", 
      "\"\<am\>\"", ",", "\"\<learning\>\"", ",", "\"\<Wolfram\>\""}], "}"}], 
    ",", "\"\< \>\""}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.899476617134982*^9},
 CellLabel->
  "In[127]:=",ExpressionUUID->"a537ab76-1416-4408-8a0f-66cb39b7c7c9"],

Cell[BoxData["\<\"hello world I am learning Wolfram\"\>"], "Output",
 CellChangeTimes->{3.8994766180914383`*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"d4c79381-f0d8-49da-93e2-e4c3987e0416"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using templates", "Subsection",
 CellChangeTimes->{{3.89947727928196*^9, 
  3.899477283483097*^9}},ExpressionUUID->"ee5f01f1-9eab-482e-9d39-\
2cde96652dad"],

Cell["\<\
A cool thing we can do with strings is insert a piece of text into another \
piece of text using a template and the Rule function:\
\>", "Text",
 CellChangeTimes->{{3.8994772857040586`*^9, 3.899477314889271*^9}, {
  3.899477554938978*^9, 
  3.899477560493681*^9}},ExpressionUUID->"8231692c-7584-433e-ace0-\
f87cb3644377"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringTemplate", "[", "\"\<My name is `name`\>\"", "]"}], "[", 
  RowBox[{"<|", 
   RowBox[{"\"\<name\>\"", "->", " ", "\"\<Harry Potter\>\""}], "|>"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.899477316204795*^9, 3.8994773652001257`*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"fd05f16f-3299-4da9-be23-df552ae9ef90"],

Cell[BoxData["\<\"My name is Harry Potter\"\>"], "Output",
 CellChangeTimes->{{3.899477345932876*^9, 3.8994773657416487`*^9}},
 CellLabel->
  "Out[129]=",ExpressionUUID->"97b4b1fb-5526-47f7-9240-e65a408789e0"]
}, Open  ]],

Cell["We can do this multiple times:", "Text",
 CellChangeTimes->{{3.899477371935491*^9, 
  3.899477377542335*^9}},ExpressionUUID->"6c2ccad2-6a67-48c2-8627-\
7d69a0617e76"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
  "StringTemplate", "[", 
   "\"\<My name is `name` and I am in `house` House\>\"", "]"}], "[", 
  RowBox[{"<|", 
   RowBox[{
    RowBox[{"\"\<name\>\"", "->", "\"\<Harry Potter\>\""}], ",", 
    RowBox[{"\"\<house\>\"", "->", "\"\<Gryffindor\>\""}]}], "|>"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.899477378615856*^9, 3.89947742267693*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"7ef08601-368f-4593-9017-2d0739e13bf8"],

Cell[BoxData["\<\"My name is Harry Potter and I am in Gryffindor House\"\>"], \
"Output",
 CellChangeTimes->{3.899477423233657*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"d046d4ac-8731-44ac-836e-5b18a1a08a5c"]
}, Open  ]],

Cell["\<\
We can even evaluate some code before we put it into the string using \
RuleDelayed:\
\>", "Text",
 CellChangeTimes->{{3.899477479985364*^9, 3.899477501752511*^9}, {
  3.899477566443207*^9, 
  3.899477569875978*^9}},ExpressionUUID->"d7573f58-b989-4336-99ce-\
ed66845d9e01"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
  "StringTemplate", "[", "\"\<My favorite number is `number`\>\"", "]"}], "[", 
  RowBox[{"<|", 
   RowBox[{"\"\<number\>\"", ":>", 
    RowBox[{"RandomInteger", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "100"}], "}"}], "]"}]}], "|>"}], "]"}]], "Input",
 CellChangeTimes->{{3.899477503356278*^9, 3.8994775447111053`*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"164c8c09-97d4-4995-93d1-5c6bf01bc8a7"],

Cell[BoxData["\<\"My favorite number is 67\"\>"], "Output",
 CellChangeTimes->{3.899477545605811*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"b907ca79-44c5-4c87-9a26-a40f80a9cc8b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Selecting items in a list based on a criteria", "Subsection",
 CellChangeTimes->{{3.899477628201618*^9, 
  3.8994776527303047`*^9}},ExpressionUUID->"d24901ae-301d-4522-927d-\
ec7026c74f3e"],

Cell["\<\
We might want to choose a string that has some specific property, like being \
a certain length. We can do this using the function Select. Select tests to \
see if each item in the list meets a set criteria, and outputs all the items \
that meet the criteria:\
\>", "Text",
 CellChangeTimes->{{3.899477654852201*^9, 3.899477739956565*^9}, {
  3.902331278458601*^9, 
  3.902331278896205*^9}},ExpressionUUID->"fe4c6ce0-d8d6-453e-b743-\
fbe60755f1fe"],

Cell["\<\
For example, we could say that the criteria is that the number needs to be \
bigger than 3:\
\>", "Text",
 CellChangeTimes->{{3.899477773841069*^9, 
  3.899477790882238*^9}},ExpressionUUID->"d6f1cd6e-2344-4d78-8333-\
6abba56d0df7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
   RowBox[{
    RowBox[{"#", ">", "3"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.899477744549013*^9, 3.89947776728338*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"ec2537af-fa9f-4175-b706-1ab677c2f913"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "5"}], "}"}]], "Output",
 CellChangeTimes->{3.89947776795936*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"90783e9e-d055-4982-bbb3-1e298b67a29f"]
}, Open  ]],

Cell["\<\
Above we are using a pure anonymous function. The slot (#) just means \
\[OpenCurlyQuote]the one you\[CloseCurlyQuote]re looking at right now\
\[CloseCurlyQuote] - Select looks at the first item, then the second item \
etc.. Remember that the ampersand (&) just tells Wolfram that everything \
before the ampersand should be considered part of the function.\
\>", "Text",
 CellChangeTimes->{{3.899477796593089*^9, 3.899477859519618*^9}, {
  3.899478513987631*^9, 3.8994785222925987`*^9}, {3.902331297967865*^9, 
  3.9023313549950943`*^9}},ExpressionUUID->"ad7a4d90-e6c1-408f-b2f4-\
0d6c199d1369"],

Cell["\<\
So let\[CloseCurlyQuote]s figure out how to do this on a string to find all \
the strings in a list which have the length 5. We would use the function \
StringLength to see how long a string is:\
\>", "Text",
 CellChangeTimes->{{3.899477741618143*^9, 3.899477743764916*^9}, {
  3.899477867258485*^9, 
  3.8994779252281647`*^9}},ExpressionUUID->"728038c8-1e79-4962-bb87-\
131f5c632a07"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringLength", "[", "\"\<hello\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.8994778783525057`*^9, 3.899477910987399*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"f24e357c-955d-49a5-801f-bc08a587e224"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{{3.8994778883785067`*^9, 3.899477911523715*^9}},
 CellLabel->
  "Out[134]=",ExpressionUUID->"1b4810a9-f883-4265-aaac-399ea52ec658"]
}, Open  ]],

Cell["\<\
We can test if something is true using operators. Some of the most common \
operators are == to test if two things are the same, > to test if the first \
thing is bigger than the second thing, and < to test if the second thing is \
bigger than the first thing:\
\>", "Text",
 CellChangeTimes->{{3.8994780377289457`*^9, 
  3.8994781161228437`*^9}},ExpressionUUID->"157ee938-f1e3-480e-a046-\
f8a60f3e33d1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringLength", "[", "\"\<hello\>\"", "]"}], "==", "5"}]], "Input",
 CellChangeTimes->{{3.8994781176789637`*^9, 3.899478124222364*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"548e95da-3d6c-4722-b612-cb2116041eb2"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.899478124736678*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"1643ad32-e5e8-49f6-92dd-af7899419291"]
}, Open  ]],

Cell["\<\
We can combine these two facts into Select. Select will look at each item in \
the list, and run the test on it - in this case, it\[CloseCurlyQuote]s \
testing if the output of StringLength is equal to 5. If the test is True, \
Select will give us that item. If it\[CloseCurlyQuote]s False, it won\
\[CloseCurlyQuote]t give us anything for that item:\
\>", "Text",
 CellChangeTimes->{{3.89947812828091*^9, 
  3.89947820617035*^9}},ExpressionUUID->"c5e764ab-39f3-425f-90f0-\
5fc407f0a631"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<hello\>\"", ",", "\"\<goodbye\>\"", ",", "\"\<I am a string\>\"", 
     ",", "\"\<My name is Harry Potter\>\"", ",", "\"\<Harry\>\""}], "}"}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"StringLength", "[", "#", "]"}], "==", "5"}], "&"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8994779269459*^9, 3.899477966783017*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"5b5cbd5e-05e8-4a47-a24f-cc4441c1fbe8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"hello\"\>", ",", "\<\"Harry\"\>"}], "}"}]], "Output",
 CellChangeTimes->{{3.899477953860949*^9, 3.89947796732437*^9}},
 CellLabel->
  "Out[136]=",ExpressionUUID->"d7ff0e0f-0432-4d0e-8756-61d47091f735"]
}, Open  ]],

Cell["\<\
We can use any criteria we want inside Select, as long as the output is \
either True or False.\
\>", "Text",
 CellChangeTimes->{{3.899478009442416*^9, 
  3.899478034361123*^9}},ExpressionUUID->"4e136f91-6bcb-4788-ac8e-\
324c88bf842b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Resource Functions", "Subsection",
 CellChangeTimes->{{3.8994782155020037`*^9, 
  3.8994782197371273`*^9}},ExpressionUUID->"6b11201a-f3a6-49d4-b4e6-\
7ee787e023ae"],

Cell[TextData[{
 "The last thing to know before going into this Adventure is how to use the \
",
 ButtonBox["Wolfram Function Repository",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/"], None},
  ButtonNote->"https://resources.wolframcloud.com/FunctionRepository/"],
 ". The Function Repository is full of interesting functions that we can use \
in Wolfram Language, but haven\[CloseCurlyQuote]t been built into the full \
system yet. Some of them are funny:"
}], "Text",
 CellChangeTimes->{{3.899478221531411*^9, 
  3.899478308320903*^9}},ExpressionUUID->"ea55a498-b280-4ec7-b549-\
2efc2ee6edb1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ResourceFunction", "[", "\"\<Uwuify\>\"", "]"}], "[", 
  "\"\<This is a string, it's crazy!\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.8994783198236113`*^9, 3.89947831983477*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"21518b62-02e4-4741-b495-5c082e75e2db"],

Cell[BoxData["\<\"Dis is a stwing, iwt's cwazy!\"\>"], "Output",
 CellChangeTimes->{3.899478324577511*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"5309c484-b60a-401f-a94e-556436936764"]
}, Open  ]],

Cell["And there are lots of useful functions too.", "Text",
 CellChangeTimes->{{3.899478366932939*^9, 
  3.8994783733410892`*^9}},ExpressionUUID->"b6e52cf9-a547-4972-8945-\
89b623a254a9"],

Cell["\<\
We\[CloseCurlyQuote]ll be using a function from the FunctionRepository in \
this Adventure. You need to know the name of the function in order to call it \
- so you usually need to go to the Function Repository website to find what \
you need. From there, you can click on the function name to copy it and paste \
it into the notebook, or you can type it out using the syntax above.\
\>", "Text",
 CellChangeTimes->{{3.89947838495759*^9, 3.899478484287897*^9}, 
   3.899478519407145*^9},ExpressionUUID->"815e755f-0859-404d-8837-\
dfe0fae69e8b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Activities", "Section",
 CellChangeTimes->{{3.899397066302799*^9, 
  3.899397068268853*^9}},ExpressionUUID->"5f11be89-dc8d-4e6e-84e2-\
fc08d0ea3482"],

Cell["\<\
Let\[CloseCurlyQuote]s generate some computational poetry! In this adventure, \
you\[CloseCurlyQuote]re going to create two different types of poems: Mad \
Libs and Haiku.\
\>", "Text",
 CellChangeTimes->{{3.899478563522168*^9, 
  3.8994786090712442`*^9}},ExpressionUUID->"41c50f9f-3bc6-4bd0-9256-\
5c9ec25cf106"],

Cell[CellGroupData[{

Cell["Mad Libs", "Subsection",
 CellChangeTimes->{{3.899397070417592*^9, 
  3.899397071619417*^9}},ExpressionUUID->"150b7fa0-267e-4788-a6d1-\
80fa6ebbfc32"],

Cell["\<\
A Mad Libs poem is made by taking a piece of text with gaps to fill in, and \
filling in the gaps with your own words. For this Adventure, you\
\[CloseCurlyQuote]re going to start with this poem, \
\[OpenCurlyDoubleQuote]The Flying Carpet\[CloseCurlyDoubleQuote], by Viktor \
Vasnetsov (1880)\
\>", "Text",
 CellChangeTimes->{{3.899478613759169*^9, 
  3.899478672939624*^9}},ExpressionUUID->"c6816cc1-bf58-4b3b-82d6-\
7f7602edd49f"],

Cell[TextData[StyleBox["If I had a magic carpet or a giant set of wings,\nI\
\[CloseCurlyQuote]d leave this world of parking lots and noise and motor \
cars,\nAnd I\[CloseCurlyQuote]d fly to far off places, and \
I\[CloseCurlyQuote]d see a million things,\nAnd I\[CloseCurlyQuote]d sleep \
beneath a canopy of fifty million stars.",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.899397795841565*^9, 3.8993978067434893`*^9}, {
  3.8994786700960913`*^9, 
  3.8994786773152*^9}},ExpressionUUID->"b3f8610e-6e64-4739-ba5b-c3ad3d89cf59"],

Cell["Make a new poem that puts random words into the gaps:", "Text",
 CellChangeTimes->{{3.899478698361289*^9, 
  3.899478716401528*^9}},ExpressionUUID->"a5d41192-ee45-408a-b6ef-\
e766787ee123"],

Cell[TextData[StyleBox["If I had a magic _____ or a giant set of _____,\nI\
\[CloseCurlyQuote]d leave this world of _____ and _____ and _____,\nAnd I\
\[CloseCurlyQuote]d _____ to far off places, and I\[CloseCurlyQuote]d see a  \
_____ things,\nAnd I\[CloseCurlyQuote]d  _____ beneath a canopy of  _____  \
_____.",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{{3.899397795841565*^9, 3.8993978067434893`*^9}, {
  3.8994786700960913`*^9, 3.8994786773152*^9}, {3.8994787267442408`*^9, 
  3.8994787691440372`*^9}},ExpressionUUID->"dd2d0d03-13e3-4efb-942a-\
08ea7cc107a2"],

Cell["For example:", "Text",
 CellChangeTimes->{{3.899478787661125*^9, 
  3.899478790027876*^9}},ExpressionUUID->"ba52d3c8-ddfd-4ba0-b145-\
5b104722d1ad"],

Cell[BoxData["\<\"If I had a magic poster or a giant set of earlobes,\\nI\
\[CloseCurlyQuote]d climb this world of croaks and nightshirts and \
laws,\\nAnd I\[CloseCurlyQuote]d scream to far off places, and I\
\[CloseCurlyQuote]d see a sixty\[Hyphen]one million, one hundred sixteen \
thousand, two hundred sixty\[Hyphen]one things,\\nAnd I\[CloseCurlyQuote]d \
churn beneath a canopy of seventy\[Hyphen]seven million, five hundred forty\
\[Hyphen]seven thousand, six hundred sixty\[Hyphen]five bankbooks.\"\>"], \
"Output",
 CellChangeTimes->{{3.8994788667614813`*^9, 3.899478884451664*^9}},
 CellLabel->
  "Out[141]=",ExpressionUUID->"9abaaf8b-b3d9-4265-a4b0-1a9faeaa16dd"],

Cell[CellGroupData[{

Cell["Hint:", "Subsubsection",
 CellChangeTimes->{{3.899478894974723*^9, 
  3.899478896574813*^9}},ExpressionUUID->"075af583-6c91-4269-bec3-\
71c41fa11f46"],

Cell["The basic steps are:", "Text",
 CellChangeTimes->{{3.899478900103306*^9, 3.8994789043102303`*^9}, {
  3.902331456975555*^9, 
  3.902331457184225*^9}},ExpressionUUID->"20d96a17-a638-4efd-bbcd-\
bfcc0c9c9ea1"],

Cell["Make a template for the poem", "Item",
 CellChangeTimes->{{3.899478906411202*^9, 
  3.899478912265438*^9}},ExpressionUUID->"8ac58c4f-ca82-4690-86c8-\
8d107d4efb2b"],

Cell["\<\
Decide if you want to specify the part of speech (noun, verb etc.) for your \
random words\
\>", "Item",
 CellChangeTimes->{{3.899478906411202*^9, 
  3.899478948016864*^9}},ExpressionUUID->"4fc68744-8c18-4ca9-a493-\
814b9aad3a36"],

Cell["Put random words into the template", "Item",
 CellChangeTimes->{{3.899478906411202*^9, 
  3.8994789568408127`*^9}},ExpressionUUID->"d7c150fa-fbbd-40a2-a607-\
a1fc5dd4c0c8"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hint:", "Subsubsection",
 CellChangeTimes->{{3.8994789646268053`*^9, 
  3.89947896637889*^9}},ExpressionUUID->"b8d09e27-37ec-4178-a477-\
9223e8f28743"],

Cell["Some functions you might need to look up are:", "Text",
 CellChangeTimes->{{3.899478968674479*^9, 3.8994789743307123`*^9}, {
  3.902331533671784*^9, 
  3.902331534084483*^9}},ExpressionUUID->"0c02e3e8-cac2-4b38-9091-\
062a312e9cf8"],

Cell["StringTemplate", "Item",
 CellChangeTimes->{{3.899478975890005*^9, 3.899478979911428*^9}, {
  3.902331536108672*^9, 
  3.9023315372605867`*^9}},ExpressionUUID->"5ffb391a-fe6e-410a-ba15-\
328197e9c289"],

Cell["RandomWord", "Item",
 CellChangeTimes->{{3.899478975890005*^9, 
  3.8994789840479937`*^9}},ExpressionUUID->"20ae750e-7063-489d-ba11-\
462dbb43af93"],

Cell["IntegerName", "Item",
 CellChangeTimes->{{3.899478975890005*^9, 
  3.899478989591361*^9}},ExpressionUUID->"d4cd6236-6685-424a-b92f-\
aae6adb59634"],

Cell["RandomInteger", "Item",
 CellChangeTimes->{{3.899478975890005*^9, 
  3.8994789938187323`*^9}},ExpressionUUID->"e83007cc-f8b8-4e38-bba3-\
ceef5a5f2692"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Haiku", "Subsection",
 CellChangeTimes->{{3.899398504876186*^9, 
  3.899398506426923*^9}},ExpressionUUID->"bc42c7a9-5566-40d3-a132-\
b8f30a15b91d"],

Cell["\<\
A Haiku is a short poem with three lines. The first line has 5 syllables, the \
second line has 7, and the third line has 5. Words don\[CloseCurlyQuote]t \
need to rhyme. For this Adventure, your poem doesn\[CloseCurlyQuote]t really \
need to make sense, but it will create some funny results!
You will need to use the ResourceFunction \
\[OpenCurlyDoubleQuote]WordSyllables\[CloseCurlyDoubleQuote] from the Wolfram \
Function Repository. This function splits a word into syllables.\
\>", "Text",
 CellChangeTimes->{{3.899479007536277*^9, 3.8994791597709084`*^9}, {
  3.8994803092580338`*^9, 
  3.899480316452055*^9}},ExpressionUUID->"63f32334-6526-4769-a18c-\
50d6f2007c08"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResourceFunction", "[", "\"\<WordSyllables\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.899398900059848*^9, 3.8993989000658207`*^9}},
 CellLabel->
  "In[424]:=",ExpressionUUID->"4cd73264-ef9f-474d-a3da-6725d63223be"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   TagBox[
    DynamicModuleBox[{Typeset`open = True}, 
     FrameBox[
      PaneSelectorBox[{False->GridBox[{
         {
          PaneBox[GridBox[{
             {
              StyleBox[
               StyleBox[
                AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                 BoxBaselineShift->-0.25,
                 BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                
                FontColor->RGBColor[
                 0.8745098039215686, 0.2784313725490196, 0.03137254901960784]],
               
               ShowStringCharacters->False,
               FontFamily->"Source Sans Pro Black",
               FontSize->0.6538461538461539 Inherited,
               FontWeight->"Heavy",
               PrivateFontOptions->{"OperatorSubstitution"->False}], 
              StyleBox[
               RowBox[{
                StyleBox["WordSyllables", "ResourceFunctionLabel"], " "}],
               ShowAutoStyles->False,
               ShowStringCharacters->False,
               FontSize->Rational[12, 13] Inherited,
               FontColor->GrayLevel[0.1]]}
            },
            GridBoxSpacings->{"Columns" -> {{0.25}}}],
           Alignment->Left,
           BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
           BaselinePosition->Baseline,
           FrameMargins->{{3, 0}, {0, 0}}], 
          ItemBox[
           PaneBox[
            TogglerBox[Dynamic[Typeset`open], {True->
             
             DynamicBox[FEPrivate`FrontEndResource[
              "FEBitmaps", "IconizeCloser"],
              ImageSizeCache->{11., {1., 10.}}], False->
             
             DynamicBox[FEPrivate`FrontEndResource[
              "FEBitmaps", "IconizeOpener"],
              ImageSizeCache->{11., {1., 10.}}]},
             Appearance->None,
             BaselinePosition->Baseline,
             ContentPadding->False,
             FrameMargins->0],
            Alignment->Left,
            BaselinePosition->Baseline,
            FrameMargins->{{1, 1}, {0, 0}}],
           Frame->{{
              RGBColor[
              0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
               0.5], False}, {False, False}}]}
        },
        BaselinePosition->{1, 1},
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
       GridBox[{
         {GridBox[{
            {
             PaneBox[GridBox[{
                {
                 StyleBox[
                  StyleBox[
                   AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                   
                   FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                  ShowStringCharacters->False,
                  FontFamily->"Source Sans Pro Black",
                  FontSize->0.6538461538461539 Inherited,
                  FontWeight->"Heavy",
                  PrivateFontOptions->{"OperatorSubstitution"->False}], 
                 StyleBox[
                  RowBox[{
                   StyleBox["WordSyllables", "ResourceFunctionLabel"], " "}],
                  ShowAutoStyles->False,
                  ShowStringCharacters->False,
                  FontSize->Rational[12, 13] Inherited,
                  FontColor->GrayLevel[0.1]]}
               },
               GridBoxSpacings->{"Columns" -> {{0.25}}}],
              Alignment->Left,
              BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
              BaselinePosition->Baseline,
              FrameMargins->{{3, 0}, {0, 0}}], 
             ItemBox[
              PaneBox[
               TogglerBox[Dynamic[Typeset`open], {True->
                
                DynamicBox[FEPrivate`FrontEndResource[
                 "FEBitmaps", "IconizeCloser"],
                 ImageSizeCache->{11., {1., 10.}}], False->
                
                DynamicBox[FEPrivate`FrontEndResource[
                 "FEBitmaps", "IconizeOpener"],
                 ImageSizeCache->{11., {1., 10.}}]},
                Appearance->None,
                BaselinePosition->Baseline,
                ContentPadding->False,
                FrameMargins->0],
               Alignment->Left,
               BaselinePosition->Baseline,
               FrameMargins->{{1, 1}, {0, 0}}],
              Frame->{{
                 RGBColor[
                 0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                  0.5], False}, {False, False}}]}
           },
           BaselinePosition->{1, 1},
           GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
           GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
         {
          StyleBox[
           PaneBox[GridBox[{
              {
               RowBox[{
                TagBox["\<\"Version (latest): \"\>",
                 "IconizedLabel"], " ", 
                TagBox["\<\"1.0.0\"\>",
                 "IconizedItem"]}]},
              {
               TagBox[
                
                TemplateBox[{
                 "\"Documentation \[RightGuillemet]\"", 
                  "https://resources.wolframcloud.com/FunctionRepository/\
resources/WordSyllables"},
                 "HyperlinkURL"],
                "IconizedItem"]}
             },
             DefaultBaseStyle->"Column",
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
            Alignment->Left,
            BaselinePosition->Baseline,
            FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
           FontFamily->"Roboto",
           FontSize->11]}
        },
        BaselinePosition->{1, 1},
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
        GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
             GrayLevel[0.8]}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
       Typeset`open],
       BaselinePosition->Baseline,
       ImageSize->Automatic],
      Background->RGBColor[
       0.9686274509803922, 0.9764705882352941, 0.984313725490196],
      BaselinePosition->Baseline,
      DefaultBaseStyle->{},
      FrameMargins->{{0, 0}, {1, 0}},
      FrameStyle->RGBColor[
       0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
      RoundingRadius->4]],
    #& ,
    TagBoxNote->" "],
   {"FunctionResourceBox", 
    RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
    "WordSyllables"},
   TagBoxNote->"FunctionResourceBox"],
  ResourceFunction[
   ResourceObject[<|
    "Name" -> "WordSyllables", "ShortName" -> "WordSyllables", "UUID" -> 
     "fcc429d6-4f63-4cce-8219-e9cd88b718f5", "ResourceType" -> "Function", 
     "Version" -> "1.0.0", "Description" -> 
     "Give a list of the separate English syllables of the input word", 
     "RepositoryLocation" -> 
     URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
     "SymbolName" -> 
     "FunctionRepository`$3f5ff8b93b6b48dca563bb08539418e0`WordSyllables", 
     "FunctionLocation" -> 
     CloudObject[
      "https://www.wolframcloud.com/obj/71964eab-502c-4488-a60b-226af7f38a95"]\
|>, ResourceSystemBase -> Automatic]],
  Selectable->False]], "Output",
 CellChangeTimes->{{3.899398905955036*^9, 3.89939892437011*^9}, 
   3.899399154099668*^9},
 CellLabel->
  "Out[424]=",ExpressionUUID->"76b0649f-7a8d-42ca-9c6f-239fda11d749"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ResourceFunction", "[", "\"\<WordSyllables\>\"", "]"}], "[", 
  "\"\<word\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.899479165770815*^9, 3.899479177727788*^9}},
 CellLabel->
  "In[142]:=",ExpressionUUID->"d4d0719e-ac92-4474-9b33-5c9b0ec7b11a"],

Cell[BoxData[
 RowBox[{"{", "\<\"word\"\>", "}"}]], "Output",
 CellChangeTimes->{3.899479178163411*^9},
 CellLabel->
  "Out[142]=",ExpressionUUID->"0c936447-c8fe-4b35-964b-fd8d2f9feef2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ResourceFunction", "[", "\"\<WordSyllables\>\"", "]"}], "[", 
  "\"\<bigger\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.899479186451499*^9, 3.899479190577928*^9}},
 CellLabel->
  "In[143]:=",ExpressionUUID->"7ac60696-bf15-4bbf-b3ef-5d874df9d24c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"bigg\"\>", ",", "\<\"er\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.8994791912049313`*^9},
 CellLabel->
  "Out[143]=",ExpressionUUID->"71362cfc-6e27-44ee-aa06-3c85dac41286"]
}, Open  ]],

Cell["Generate a random Haiku like these:", "Text",
 CellChangeTimes->{{3.899479205303958*^9, 3.8994792271776943`*^9}, {
  3.899479290868191*^9, 
  3.8994792914683867`*^9}},ExpressionUUID->"2c967ecf-d352-4485-8342-\
8b512e07ff48"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"postulation dill\"\>"},
    {"\<\"smelly importunity\"\>"},
    {"\<\"then heated soppy\"\>"}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{{3.899401781876882*^9, 3.899401798737774*^9}, {
   3.8994018409621*^9, 3.8994018531766863`*^9}, 3.899401883506145*^9, {
   3.899401934046934*^9, 3.89940195370325*^9}, {3.899402050828094*^9, 
   3.899402061483295*^9}, 3.899473726211816*^9, {3.899474122900419*^9, 
   3.89947414723967*^9}, 3.8994744031177673`*^9, 3.89947923368806*^9},
 CellLabel->
  "Out[144]=",ExpressionUUID->"d7624e3a-08ab-4a9a-bbd2-d064fc04f041"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"carrier nuptials\"\>"},
    {"\<\"only snowmobile aloud\"\>"},
    {"\<\"respire amethyst\"\>"}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{{3.899401781876882*^9, 3.899401798737774*^9}, {
   3.8994018409621*^9, 3.8994018531766863`*^9}, 3.899401883506145*^9, {
   3.899401934046934*^9, 3.89940195370325*^9}, {3.899402050828094*^9, 
   3.899402061483295*^9}, 3.899473726211816*^9, {3.899474122900419*^9, 
   3.89947414723967*^9}, 3.8994744031177673`*^9, {3.89947923368806*^9, 
   3.8994792747974787`*^9}},
 CellLabel->
  "Out[149]=",ExpressionUUID->"e00c75b1-6817-4f07-b0a7-e37a2e58feaa"],

Cell[CellGroupData[{

Cell["Hint:", "Subsubsection",
 CellChangeTimes->{{3.899479301530364*^9, 
  3.899479305574889*^9}},ExpressionUUID->"6f136017-581a-4e7d-a0b6-\
86acff2fdddc"],

Cell["The basic steps are:", "Text",
 CellChangeTimes->{{3.899479308414894*^9, 3.899479312491733*^9}, {
  3.902331492728311*^9, 
  3.902331493095936*^9}},ExpressionUUID->"a0bbbd32-e228-4389-8560-\
eec6dd8a126b"],

Cell["Make lots of lists of random words", "Item",
 CellChangeTimes->{{3.899479314519475*^9, 3.899479370280334*^9}, {
  3.899549760832047*^9, 
  3.899549768323855*^9}},ExpressionUUID->"191d4549-19d1-49f6-b92a-\
0c01a8f3430f"],

Cell["Select a list that has a total of 5 syllables", "Item",
 CellChangeTimes->{{3.899479314519475*^9, 3.899479370280334*^9}, {
  3.8995497610087337`*^9, 
  3.899549797557371*^9}},ExpressionUUID->"89de83a8-0f30-47dc-8903-\
6462671887a4"],

Cell["Do the same for 7 syllables and again for 5 syllables", "Item",
 CellChangeTimes->{{3.899479314519475*^9, 3.899479370280334*^9}, {
  3.8995497610087337`*^9, 
  3.899549811625351*^9}},ExpressionUUID->"c2ee2773-c6d3-40bb-a310-\
57e1696f642f"],

Cell["Join the list of words into a single string", "Item",
 CellChangeTimes->{{3.899479314519475*^9, 3.899479394161581*^9}, 
   3.8995498291280823`*^9},ExpressionUUID->"a28137dd-1e53-4d16-924b-\
fe58eaa6fb5a"],

Cell["Display the three lines in a column", "Item",
 CellChangeTimes->{{3.899479314519475*^9, 
  3.899479419389235*^9}},ExpressionUUID->"bb783001-3a7f-47fd-9535-\
90db6fcf81e2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hint:", "Subsubsection",
 CellChangeTimes->{{3.899479422188497*^9, 
  3.899479423905992*^9}},ExpressionUUID->"1792dcf6-9018-4504-a833-\
97424621ee87"],

Cell["Some functions you might need to look up are:", "Text",
 CellChangeTimes->{{3.899479426503244*^9, 3.899479433875866*^9}, {
  3.902331518452232*^9, 
  3.902331528885035*^9}},ExpressionUUID->"08168ac9-01ac-433c-90df-\
74de33c6f438"],

Cell["RandomWord", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.899479441769631*^9}},ExpressionUUID->"b43ee2e0-61aa-4987-a23d-\
02d8262a2165"],

Cell["RandomChoice", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.899479444428255*^9}},ExpressionUUID->"ff23f6dc-6771-4c8a-885a-\
c5f8cffe0054"],

Cell["Table", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.8994794460179453`*^9}},ExpressionUUID->"b9f6bd6d-d336-495f-a02c-\
be0994929ed5"],

Cell["Select", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.899479447448317*^9}},ExpressionUUID->"a50ea82e-eb6d-4f6c-aee8-\
ae418ed78ecb"],

Cell["StringJoin", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.899479453761805*^9}},ExpressionUUID->"50aea41d-72f9-49a7-ad31-\
571f182d925d"],

Cell["Length", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.8994794556776752`*^9}},ExpressionUUID->"5b0cb389-4e24-47af-b5d7-\
1dca80ce681d"],

Cell["Flatten", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.8994794576641006`*^9}},ExpressionUUID->"4f6358be-f6dd-4d0d-aeba-\
3a382d2a7177"],

Cell["==", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.899479460143869*^9}},ExpressionUUID->"4b4620e6-12ae-436a-aeac-\
0ccd8a28226c"],

Cell["Riffle", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.8994794630783567`*^9}},ExpressionUUID->"716bb08d-46e9-4637-aeee-\
e45d55934a06"],

Cell["Column", "Item",
 CellChangeTimes->{{3.8994794351473083`*^9, 
  3.899479464906706*^9}},ExpressionUUID->"05078e29-6456-45eb-9ffa-\
1c2fa0816f42"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extension: Machine Learning Poetry", "Subsection",
 CellChangeTimes->{{3.8994794965128393`*^9, 
  3.899479521744175*^9}},ExpressionUUID->"9404b1a0-e6b3-47b5-8456-\
fabb69f10bee"],

Cell["\<\
The documentation on the function SequencePredict gives an example of writing \
sentences in the style of a particular book or block of text. SequencePredict \
uses machine learning to predict the next words based on the data you give it.

Try writing some poems using the SequencePredict function. You can use any \
text you would like, and make any kind of poem that might be interesting. You \
can even try using your code for the Haiku generator to make a predicted \
Haiku, or use the Mad Libs template and ask for SequencePredict to choose the \
next word!\
\>", "Text",
 CellChangeTimes->{{3.899479528763833*^9, 3.8994797123254023`*^9}, {
  3.899550042339999*^9, 3.899550068147403*^9}, {3.902331567457437*^9, 
  3.90233156754908*^9}},ExpressionUUID->"cb6985b1-6ff9-4de7-bc53-\
553bf42eb76d"],

Cell[CellGroupData[{

Cell["Example from SequencePredict documentation", "Subsubsection",
 CellChangeTimes->{{3.899479724436692*^9, 
  3.899479737230558*^9}},ExpressionUUID->"2f1f1a82-9219-4aeb-a77a-\
a0f1a504488c"],

Cell[TextData[{
 "Load a book from ",
 Cell[BoxData[
  TemplateBox[{
    Cell[
     TextData["ExampleData"]], "paclet:ref/ExampleData"},
   "RefLink",
   BaseStyle->{"InlineFormula"}]], "InlineFormula",
  FontFamily->"Source Sans Pro",ExpressionUUID->
  "b14f76b6-1eb8-4dd9-820c-c6673289a1bd"],
 ":"
}], "Text",
 CellID->1603154666,ExpressionUUID->"a9ac614d-30a5-4fcf-b9b3-fb12927a32bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dq", "=", 
   RowBox[{"ExampleData", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<Text\>\"", ",", "\"\<DonQuixoteIEnglish\>\""}], "}"}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->1446587299,ExpressionUUID->"8e38da69-ff90-4413-9834-b88c4f5b5092"],

Cell["Train a sequence predictor on this book:", "Text",
 CellID->1327236851,ExpressionUUID->"1f0bd9d2-3ac5-4d18-953d-d2df55cdd86a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spchar", "=", 
  RowBox[{"SequencePredict", "[", 
   RowBox[{"{", "dq", "}"}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->361313456,ExpressionUUID->"b17f4db8-b3d0-43e2-848f-3145d5086baa"],

Cell[BoxData[
 TagBox[
  TemplateBox[{
    RowBox[{
      StyleBox[
       TagBox["SequencePredictorFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{{
                  Thickness[0.002], {{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     499.}, {1., 499.}, {1., 500.001}, {0., 500.001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    499., 499.}, {500.001, 499.}, {500.001, 500.001}, {499., 
                    500.001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {1., 0.}, {1., 1.}, {0., 1.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    499., 0.}, {500.001, 0.}, {500.001, 1.}, {499., 
                    1.}}}]}}, {{
                    FaceForm[{
                    RGBColor[0.604, 0.604, 0.604], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72., 426.}, {150., 426.}, {150., 348.}, {72., 348.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    347., 288.}, {425., 288.}, {425., 210.}, {347., 210.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{130.55, 132.031}, {
                    91.46900000000002, 132.031}, {91.46900000000002, 
                    92.95000000000002}, {130.55, 92.95000000000002}}, {{72., 
                    152.}, {150., 152.}, {150., 74.}, {72., 74.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{267.55, 
                    268.03099999999995`}, {228.46900000000002`, 
                    268.03099999999995`}, {228.46900000000002`, 
                    228.94999999999996`}, {267.55, 228.94999999999996`}}, {{
                    209., 288.}, {287., 288.}, {287., 210.}, {209., 210.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{267.55, 
                    405.03099999999995`}, {228.46900000000002`, 
                    405.03099999999995`}, {228.46900000000002`, 
                    365.94999999999993`}, {267.55, 365.94999999999993`}}, {{
                    209., 425.}, {287., 425.}, {287., 347.}, {209., 347.}}}], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{155., 250.}, {155., 225.147}, {134.853, 205.}, {
                    110., 205.}, {85.147, 205.}, {65., 225.147}, {65., 
                    250.}, {65., 274.853}, {85.147, 295.}, {110., 295.}, {
                    134.853, 295.}, {155., 274.853}, {155., 250.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJeKA0GChUOYPpBlYMhxxqZqEllcD6YDih1OP89+PHS
uZVwPpgWqIDzwfqaylD1O0DVwcx3gJqzthJV/kMVXD+Mj2I+kA+zH0U/zH1I
7kfhL6h0OPxVI6b/D4IPpjdAxd9UwPko9gH5tlzXFxcYl6PqbyhDNR/IB6tz
LkeVn1AG1w/jo5gP5MPsR9EPcx+S+wFHkGkl
                    "]]}}, {{
                    FaceForm[{
                    RGBColor[0.267, 0.267, 0.267], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxlk21IU2EUx5eI2NLsTVYULBMLE5GsD2UZf6P8oCJqZrrNud1tllqIxu7L
JExULN+QihQblGKi5dLENLWiF0RKxA0xS/ElE83SFSJSJtXzeGn70IfLc3/c
/3nOOf9zrg+TGWdwkUgkh8lDz1rfztWiRzysQwnzQbnxiMZW7evd3H/Mm4ny
qhKtOYstMcEczrxsqIs2K3HsWdwtHy2Hm8tuKVVWpagv5bC9wyYZd1OhnRwu
bRxOpWV+LwxVIcCwYypxmkM6wTdXVBgdzrsULuMRm1HNme0quKwvlusiebwj
6bvzk/ExUdZhu8zjD03soUYM1d3jcZsjBVnUoLJ9r3iwWTs9J7UpYj0TPN5v
WQwb8NCI8Qvkvtn0gGWjk0N8I3Ly55xMKCiqSgvVxZ7frVYee+RLFxJkDOJp
n5U8FINPP23TMSDZvDZoeBQERdVLmxis0IDNPPYaXardbQyuyXV2RTPnYLvi
xPHP2U52J+3ZA4lfRYWKwXYGddSwKVa8P58BtTHKzCJNkpnneppBr3/I9T4F
C0vJ6HmJNwPadqecxf6+Tb1db7U4d5IYu2JEvTTcz2h28ppe0INU+7heyoKo
n5QV6NF/f2AoIZQFvb6nUS/2V8hiZeHriyM2PQSacJKFl/lgbdtPvVhvJIfx
G6RgfwOIu+XGLk70L8wAWq63P+9gaqfkm5Mr7v44MFMmwJo6NJs+p0c4XZR1
JoyECokNR/UoN5LBGU2om3i+0VymE/fBYkLVGEnYwji4uZ3J/VCpdfCaf8sa
0HXMqDHBM6upZDRVI86n2ITgmYd+08Mp4jyzTViigVNqMT7WhDvUCKla/L7X
BLpGXmeT0UQH+kvACH2pUYl+9QrIJusVuKoExfliAQ/omaEEXWdZtAALjRtR
iPN0F7CLyCviFeK8unk00g9jSfj3v5VGfHE91J+Ev8kFnlk=
                    "], {{397.24569999999994`, 52.252300000000005`}, {
                    368.20269999999994`, 52.252300000000005`}, {
                    368.20269999999994`, 73.5373}, {397.24569999999994`, 
                    73.5373}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxlk3swVFEcx3ckGqEHUpNq5FFRKdNMD8m3l5EalRBr19prNdlr995L6zH+
iPQwFWOmB2kV2hFFykykZFKDRgkZ8ogkeaWmMVIM6dx2Wn/0x51zP+d8f+f3
O7/zPdYU4x2qJxAItpCPH3NsyibPWbNoaPYbdnLzgTre/vlZa8V/HKMmyqRA
hP7slWbvUcC3Mk/jpQ7E2dtHa51zFLg8ZiBJbwjEncJWSdS4Ava9iTfqDETo
u7j6q4mHEnvDmO9nXEXwyCQb5ikh2rVjoC1ehLxTh/dlmjI4TGdEq7+JMHuh
uVt1FIMWkv5JohgvHqxX3upgMF0cN3LfOAiHeJ0Fi+vRpKDCIPCyVc4soril
Jt1SCbY/9b5qfZBF68KRnfXGwfjob1naKGbR0i93HFPN8DYbz7jEwRkm5HQg
XQqRoup3MVisXDEa7mdJwYc/pyELYVP5J/MQCpKog8sXZTE47XQg16iAwmhZ
+/mpWQzsVXoZcxopmLlVv3+4Q6njkNfi/S+rFDpeQI733oX069wZYVMJpe2H
Jly7fyKFSNu06dTF4QgTMAn6RyikHDlhm3aFRuGFjuMCCwoqkl6+gobDq/k1
j2ulqEt629XdLEeukbudSj3Df/WxMtQYul73/SEHUT9KPi3DQGnRrH4hDdpx
LK0zXwbmDQkYojH8bKuNZ6MM5HZbNmWHI4mUVz4u09YbrUDXJVLwmlBo1u62
+uKj1PZvZyhMKjZcc3BmdMy3UyBhdZya9Wtj3xTx17HmfvmgDO68UTgO7a6x
/nkuMqSoyMV95qD5UGGqTg5Bx7uESPdlEUjvJAnvUzouKqFOtqVJdfy3f2PB
IK44RC+IgAlXcKHjWDCIG+bNneDg3HfPrvedRHufPRxG+cCeIG18JYebdXfq
m42CtOtXOfA2mndUjIIJMkOT+vifbBF4md9mDhHEXusmib8JDk+wuMuPNHkP
S3r8LStYFPJx7UJovGAmjWFhReSpPkLwNi1zZJHPL3QG4N97u+g5pL+pLgB/
AIGeoHU=
                    "], {{260.24569999999994`, 52.252300000000005`}, {
                    231.20369999999997`, 52.252300000000005`}, {
                    231.20369999999997`, 73.5373}, {260.24569999999994`, 
                    73.5373}}}]}}}}}, FrameStyle -> Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], Background -> GrayLevel[0.94], Axes -> 
               False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], Frame -> True, FrameTicks -> None, 
               FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Text\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Markov\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{{
                  Thickness[0.002], {{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     499.}, {1., 499.}, {1., 500.001}, {0., 500.001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    499., 499.}, {500.001, 499.}, {500.001, 500.001}, {499., 
                    500.001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {1., 0.}, {1., 1.}, {0., 1.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    499., 0.}, {500.001, 0.}, {500.001, 1.}, {499., 
                    1.}}}]}}, {{
                    FaceForm[{
                    RGBColor[0.604, 0.604, 0.604], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72., 426.}, {150., 426.}, {150., 348.}, {72., 348.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    347., 288.}, {425., 288.}, {425., 210.}, {347., 210.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{130.55, 132.031}, {
                    91.46900000000002, 132.031}, {91.46900000000002, 
                    92.95000000000002}, {130.55, 92.95000000000002}}, {{72., 
                    152.}, {150., 152.}, {150., 74.}, {72., 74.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{267.55, 
                    268.03099999999995`}, {228.46900000000002`, 
                    268.03099999999995`}, {228.46900000000002`, 
                    228.94999999999996`}, {267.55, 228.94999999999996`}}, {{
                    209., 288.}, {287., 288.}, {287., 210.}, {209., 210.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{267.55, 
                    405.03099999999995`}, {228.46900000000002`, 
                    405.03099999999995`}, {228.46900000000002`, 
                    365.94999999999993`}, {267.55, 365.94999999999993`}}, {{
                    209., 425.}, {287., 425.}, {287., 347.}, {209., 347.}}}], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{155., 250.}, {155., 225.147}, {134.853, 205.}, {
                    110., 205.}, {85.147, 205.}, {65., 225.147}, {65., 
                    250.}, {65., 274.853}, {85.147, 295.}, {110., 295.}, {
                    134.853, 295.}, {155., 274.853}, {155., 250.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJeKA0GChUOYPpBlYMhxxqZqEllcD6YDih1OP89+PHS
uZVwPpgWqIDzwfqaylD1O0DVwcx3gJqzthJV/kMVXD+Mj2I+kA+zH0U/zH1I
7kfhL6h0OPxVI6b/D4IPpjdAxd9UwPko9gH5tlzXFxcYl6PqbyhDNR/IB6tz
LkeVn1AG1w/jo5gP5MPsR9EPcx+S+wFHkGkl
                    "]]}}, {{
                    FaceForm[{
                    RGBColor[0.267, 0.267, 0.267], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxlk21IU2EUx5eI2NLsTVYULBMLE5GsD2UZf6P8oCJqZrrNud1tllqIxu7L
JExULN+QihQblGKi5dLENLWiF0RKxA0xS/ElE83SFSJSJtXzeGn70IfLc3/c
/3nOOf9zrg+TGWdwkUgkh8lDz1rfztWiRzysQwnzQbnxiMZW7evd3H/Mm4ny
qhKtOYstMcEczrxsqIs2K3HsWdwtHy2Hm8tuKVVWpagv5bC9wyYZd1OhnRwu
bRxOpWV+LwxVIcCwYypxmkM6wTdXVBgdzrsULuMRm1HNme0quKwvlusiebwj
6bvzk/ExUdZhu8zjD03soUYM1d3jcZsjBVnUoLJ9r3iwWTs9J7UpYj0TPN5v
WQwb8NCI8Qvkvtn0gGWjk0N8I3Ly55xMKCiqSgvVxZ7frVYee+RLFxJkDOJp
n5U8FINPP23TMSDZvDZoeBQERdVLmxis0IDNPPYaXardbQyuyXV2RTPnYLvi
xPHP2U52J+3ZA4lfRYWKwXYGddSwKVa8P58BtTHKzCJNkpnneppBr3/I9T4F
C0vJ6HmJNwPadqecxf6+Tb1db7U4d5IYu2JEvTTcz2h28ppe0INU+7heyoKo
n5QV6NF/f2AoIZQFvb6nUS/2V8hiZeHriyM2PQSacJKFl/lgbdtPvVhvJIfx
G6RgfwOIu+XGLk70L8wAWq63P+9gaqfkm5Mr7v44MFMmwJo6NJs+p0c4XZR1
JoyECokNR/UoN5LBGU2om3i+0VymE/fBYkLVGEnYwji4uZ3J/VCpdfCaf8sa
0HXMqDHBM6upZDRVI86n2ITgmYd+08Mp4jyzTViigVNqMT7WhDvUCKla/L7X
BLpGXmeT0UQH+kvACH2pUYl+9QrIJusVuKoExfliAQ/omaEEXWdZtAALjRtR
iPN0F7CLyCviFeK8unk00g9jSfj3v5VGfHE91J+Ev8kFnlk=
                    "], {{397.24569999999994`, 52.252300000000005`}, {
                    368.20269999999994`, 52.252300000000005`}, {
                    368.20269999999994`, 73.5373}, {397.24569999999994`, 
                    73.5373}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxlk3swVFEcx3ckGqEHUpNq5FFRKdNMD8m3l5EalRBr19prNdlr995L6zH+
iPQwFWOmB2kV2hFFykykZFKDRgkZ8ogkeaWmMVIM6dx2Wn/0x51zP+d8f+f3
O7/zPdYU4x2qJxAItpCPH3NsyibPWbNoaPYbdnLzgTre/vlZa8V/HKMmyqRA
hP7slWbvUcC3Mk/jpQ7E2dtHa51zFLg8ZiBJbwjEncJWSdS4Ava9iTfqDETo
u7j6q4mHEnvDmO9nXEXwyCQb5ikh2rVjoC1ehLxTh/dlmjI4TGdEq7+JMHuh
uVt1FIMWkv5JohgvHqxX3upgMF0cN3LfOAiHeJ0Fi+vRpKDCIPCyVc4soril
Jt1SCbY/9b5qfZBF68KRnfXGwfjob1naKGbR0i93HFPN8DYbz7jEwRkm5HQg
XQqRoup3MVisXDEa7mdJwYc/pyELYVP5J/MQCpKog8sXZTE47XQg16iAwmhZ
+/mpWQzsVXoZcxopmLlVv3+4Q6njkNfi/S+rFDpeQI733oX069wZYVMJpe2H
Jly7fyKFSNu06dTF4QgTMAn6RyikHDlhm3aFRuGFjuMCCwoqkl6+gobDq/k1
j2ulqEt629XdLEeukbudSj3Df/WxMtQYul73/SEHUT9KPi3DQGnRrH4hDdpx
LK0zXwbmDQkYojH8bKuNZ6MM5HZbNmWHI4mUVz4u09YbrUDXJVLwmlBo1u62
+uKj1PZvZyhMKjZcc3BmdMy3UyBhdZya9Wtj3xTx17HmfvmgDO68UTgO7a6x
/nkuMqSoyMV95qD5UGGqTg5Bx7uESPdlEUjvJAnvUzouKqFOtqVJdfy3f2PB
IK44RC+IgAlXcKHjWDCIG+bNneDg3HfPrvedRHufPRxG+cCeIG18JYebdXfq
m42CtOtXOfA2mndUjIIJMkOT+vifbBF4md9mDhHEXusmib8JDk+wuMuPNHkP
S3r8LStYFPJx7UJovGAmjWFhReSpPkLwNi1zZJHPL3QG4N97u+g5pL+pLgB/
AIGeoHU=
                    "], {{260.24569999999994`, 52.252300000000005`}, {
                    231.20369999999997`, 52.252300000000005`}, {
                    231.20369999999997`, 73.5373}, {260.24569999999994`, 
                    73.5373}}}]}}}}}, FrameStyle -> Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], Background -> GrayLevel[0.94], Axes -> 
               False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], Frame -> True, FrameTicks -> None, 
               FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Text\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Markov\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Number of tokens: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["65", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Markov order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["7", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("SequencePredictorFunction[\[Ellipsis]]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellLabel->"Out[2]=",
 CellID->1573551892,ExpressionUUID->"8440793e-d4d9-4040-84a4-5a4461e2228f"]
}, Open  ]],

Cell["Sample a random string in the book style:", "Text",
 CellID->973282071,ExpressionUUID->"2de7c40c-f109-480d-8c83-56b455a434f6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spchar", "[", 
  RowBox[{
   RowBox[{"{", "\"\<thou \>\"", "}"}], ",", 
   RowBox[{"\"\<RandomNextElement\>\"", "\[Rule]", "20"}]}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->430347037,ExpressionUUID->"daafc5f0-2111-4dac-9d48-513d6a38c44c"],

Cell[BoxData[
 RowBox[{"{", "\<\"wilt depended the ga\"\>", "}"}]], "Output",
 CellLabel->"Out[3]=",
 CellID->1150286512,ExpressionUUID->"49cf8bb8-fdd8-47fd-bedc-7f5e6d345d23"]
}, Open  ]],

Cell["\<\
Train another sequence predictor, interpreting strings as word sequences \
rather than character sequences:\
\>", "Text",
 CellID->1204346087,ExpressionUUID->"317b9859-6987-4d8b-8dfd-1f0a8d6c27cd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spword", "=", 
  RowBox[{"SequencePredict", "[", 
   RowBox[{
    RowBox[{"{", "dq", "}"}], ",", 
    RowBox[{"FeatureExtractor", "\[Rule]", "\"\<SegmentedWords\>\""}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[4]:=",
 CellID->398119440,ExpressionUUID->"0c9fb804-7de0-42f0-b797-77ae5ad7f63c"],

Cell[BoxData[
 TagBox[
  TemplateBox[{
    RowBox[{
      StyleBox[
       TagBox["SequencePredictorFunction", "SummaryHead"], 
       "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{{
                  Thickness[0.002], {{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     499.}, {1., 499.}, {1., 500.001}, {0., 500.001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    499., 499.}, {500.001, 499.}, {500.001, 500.001}, {499., 
                    500.001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {1., 0.}, {1., 1.}, {0., 1.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    499., 0.}, {500.001, 0.}, {500.001, 1.}, {499., 
                    1.}}}]}}, {{
                    FaceForm[{
                    RGBColor[0.604, 0.604, 0.604], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72., 426.}, {150., 426.}, {150., 348.}, {72., 348.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    347., 288.}, {425., 288.}, {425., 210.}, {347., 210.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{130.55, 132.031}, {
                    91.46900000000002, 132.031}, {91.46900000000002, 
                    92.95000000000002}, {130.55, 92.95000000000002}}, {{72., 
                    152.}, {150., 152.}, {150., 74.}, {72., 74.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{267.55, 
                    268.03099999999995`}, {228.46900000000002`, 
                    268.03099999999995`}, {228.46900000000002`, 
                    228.94999999999996`}, {267.55, 228.94999999999996`}}, {{
                    209., 288.}, {287., 288.}, {287., 210.}, {209., 210.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{267.55, 
                    405.03099999999995`}, {228.46900000000002`, 
                    405.03099999999995`}, {228.46900000000002`, 
                    365.94999999999993`}, {267.55, 365.94999999999993`}}, {{
                    209., 425.}, {287., 425.}, {287., 347.}, {209., 347.}}}], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{155., 250.}, {155., 225.147}, {134.853, 205.}, {
                    110., 205.}, {85.147, 205.}, {65., 225.147}, {65., 
                    250.}, {65., 274.853}, {85.147, 295.}, {110., 295.}, {
                    134.853, 295.}, {155., 274.853}, {155., 250.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJeKA0GChUOYPpBlYMhxxqZqEllcD6YDih1OP89+PHS
uZVwPpgWqIDzwfqaylD1O0DVwcx3gJqzthJV/kMVXD+Mj2I+kA+zH0U/zH1I
7kfhL6h0OPxVI6b/D4IPpjdAxd9UwPko9gH5tlzXFxcYl6PqbyhDNR/IB6tz
LkeVn1AG1w/jo5gP5MPsR9EPcx+S+wFHkGkl
                    "]]}}, {{
                    FaceForm[{
                    RGBColor[0.267, 0.267, 0.267], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxlk21IU2EUx5eI2NLsTVYULBMLE5GsD2UZf6P8oCJqZrrNud1tllqIxu7L
JExULN+QihQblGKi5dLENLWiF0RKxA0xS/ElE83SFSJSJtXzeGn70IfLc3/c
/3nOOf9zrg+TGWdwkUgkh8lDz1rfztWiRzysQwnzQbnxiMZW7evd3H/Mm4ny
qhKtOYstMcEczrxsqIs2K3HsWdwtHy2Hm8tuKVVWpagv5bC9wyYZd1OhnRwu
bRxOpWV+LwxVIcCwYypxmkM6wTdXVBgdzrsULuMRm1HNme0quKwvlusiebwj
6bvzk/ExUdZhu8zjD03soUYM1d3jcZsjBVnUoLJ9r3iwWTs9J7UpYj0TPN5v
WQwb8NCI8Qvkvtn0gGWjk0N8I3Ly55xMKCiqSgvVxZ7frVYee+RLFxJkDOJp
n5U8FINPP23TMSDZvDZoeBQERdVLmxis0IDNPPYaXardbQyuyXV2RTPnYLvi
xPHP2U52J+3ZA4lfRYWKwXYGddSwKVa8P58BtTHKzCJNkpnneppBr3/I9T4F
C0vJ6HmJNwPadqecxf6+Tb1db7U4d5IYu2JEvTTcz2h28ppe0INU+7heyoKo
n5QV6NF/f2AoIZQFvb6nUS/2V8hiZeHriyM2PQSacJKFl/lgbdtPvVhvJIfx
G6RgfwOIu+XGLk70L8wAWq63P+9gaqfkm5Mr7v44MFMmwJo6NJs+p0c4XZR1
JoyECokNR/UoN5LBGU2om3i+0VymE/fBYkLVGEnYwji4uZ3J/VCpdfCaf8sa
0HXMqDHBM6upZDRVI86n2ITgmYd+08Mp4jyzTViigVNqMT7WhDvUCKla/L7X
BLpGXmeT0UQH+kvACH2pUYl+9QrIJusVuKoExfliAQ/omaEEXWdZtAALjRtR
iPN0F7CLyCviFeK8unk00g9jSfj3v5VGfHE91J+Ev8kFnlk=
                    "], {{397.24569999999994`, 52.252300000000005`}, {
                    368.20269999999994`, 52.252300000000005`}, {
                    368.20269999999994`, 73.5373}, {397.24569999999994`, 
                    73.5373}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxlk3swVFEcx3ckGqEHUpNq5FFRKdNMD8m3l5EalRBr19prNdlr995L6zH+
iPQwFWOmB2kV2hFFykykZFKDRgkZ8ogkeaWmMVIM6dx2Wn/0x51zP+d8f+f3
O7/zPdYU4x2qJxAItpCPH3NsyibPWbNoaPYbdnLzgTre/vlZa8V/HKMmyqRA
hP7slWbvUcC3Mk/jpQ7E2dtHa51zFLg8ZiBJbwjEncJWSdS4Ava9iTfqDETo
u7j6q4mHEnvDmO9nXEXwyCQb5ikh2rVjoC1ehLxTh/dlmjI4TGdEq7+JMHuh
uVt1FIMWkv5JohgvHqxX3upgMF0cN3LfOAiHeJ0Fi+vRpKDCIPCyVc4soril
Jt1SCbY/9b5qfZBF68KRnfXGwfjob1naKGbR0i93HFPN8DYbz7jEwRkm5HQg
XQqRoup3MVisXDEa7mdJwYc/pyELYVP5J/MQCpKog8sXZTE47XQg16iAwmhZ
+/mpWQzsVXoZcxopmLlVv3+4Q6njkNfi/S+rFDpeQI733oX069wZYVMJpe2H
Jly7fyKFSNu06dTF4QgTMAn6RyikHDlhm3aFRuGFjuMCCwoqkl6+gobDq/k1
j2ulqEt629XdLEeukbudSj3Df/WxMtQYul73/SEHUT9KPi3DQGnRrH4hDdpx
LK0zXwbmDQkYojH8bKuNZ6MM5HZbNmWHI4mUVz4u09YbrUDXJVLwmlBo1u62
+uKj1PZvZyhMKjZcc3BmdMy3UyBhdZya9Wtj3xTx17HmfvmgDO68UTgO7a6x
/nkuMqSoyMV95qD5UGGqTg5Bx7uESPdlEUjvJAnvUzouKqFOtqVJdfy3f2PB
IK44RC+IgAlXcKHjWDCIG+bNneDg3HfPrvedRHufPRxG+cCeIG18JYebdXfq
m42CtOtXOfA2mndUjIIJMkOT+vifbBF4md9mDhHEXusmib8JDk+wuMuPNHkP
S3r8LStYFPJx7UJovGAmjWFhReSpPkLwNi1zZJHPL3QG4N97u+g5pL+pLgB/
AIGeoHU=
                    "], {{260.24569999999994`, 52.252300000000005`}, {
                    231.20369999999997`, 52.252300000000005`}, {
                    231.20369999999997`, 73.5373}, {260.24569999999994`, 
                    73.5373}}}]}}}}}, FrameStyle -> Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], Background -> GrayLevel[0.94], Axes -> 
               False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], Frame -> True, FrameTicks -> None, 
               FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Text\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Markov\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{{
                  Thickness[0.002], {{
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     499.}, {1., 499.}, {1., 500.001}, {0., 500.001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    499., 499.}, {500.001, 499.}, {500.001, 500.001}, {499., 
                    500.001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {1., 0.}, {1., 1.}, {0., 1.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    499., 0.}, {500.001, 0.}, {500.001, 1.}, {499., 
                    1.}}}]}}, {{
                    FaceForm[{
                    RGBColor[0.604, 0.604, 0.604], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72., 426.}, {150., 426.}, {150., 348.}, {72., 348.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    347., 288.}, {425., 288.}, {425., 210.}, {347., 210.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{130.55, 132.031}, {
                    91.46900000000002, 132.031}, {91.46900000000002, 
                    92.95000000000002}, {130.55, 92.95000000000002}}, {{72., 
                    152.}, {150., 152.}, {150., 74.}, {72., 74.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{267.55, 
                    268.03099999999995`}, {228.46900000000002`, 
                    268.03099999999995`}, {228.46900000000002`, 
                    228.94999999999996`}, {267.55, 228.94999999999996`}}, {{
                    209., 288.}, {287., 288.}, {287., 210.}, {209., 210.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{267.55, 
                    405.03099999999995`}, {228.46900000000002`, 
                    405.03099999999995`}, {228.46900000000002`, 
                    365.94999999999993`}, {267.55, 365.94999999999993`}}, {{
                    209., 425.}, {287., 425.}, {287., 347.}, {209., 347.}}}], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{155., 250.}, {155., 225.147}, {134.853, 205.}, {
                    110., 205.}, {85.147, 205.}, {65., 225.147}, {65., 
                    250.}, {65., 274.853}, {85.147, 295.}, {110., 295.}, {
                    134.853, 295.}, {155., 274.853}, {155., 250.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJeKA0GChUOYPpBlYMhxxqZqEllcD6YDih1OP89+PHS
uZVwPpgWqIDzwfqaylD1O0DVwcx3gJqzthJV/kMVXD+Mj2I+kA+zH0U/zH1I
7kfhL6h0OPxVI6b/D4IPpjdAxd9UwPko9gH5tlzXFxcYl6PqbyhDNR/IB6tz
LkeVn1AG1w/jo5gP5MPsR9EPcx+S+wFHkGkl
                    "]]}}, {{
                    FaceForm[{
                    RGBColor[0.267, 0.267, 0.267], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxlk21IU2EUx5eI2NLsTVYULBMLE5GsD2UZf6P8oCJqZrrNud1tllqIxu7L
JExULN+QihQblGKi5dLENLWiF0RKxA0xS/ElE83SFSJSJtXzeGn70IfLc3/c
/3nOOf9zrg+TGWdwkUgkh8lDz1rfztWiRzysQwnzQbnxiMZW7evd3H/Mm4ny
qhKtOYstMcEczrxsqIs2K3HsWdwtHy2Hm8tuKVVWpagv5bC9wyYZd1OhnRwu
bRxOpWV+LwxVIcCwYypxmkM6wTdXVBgdzrsULuMRm1HNme0quKwvlusiebwj
6bvzk/ExUdZhu8zjD03soUYM1d3jcZsjBVnUoLJ9r3iwWTs9J7UpYj0TPN5v
WQwb8NCI8Qvkvtn0gGWjk0N8I3Ly55xMKCiqSgvVxZ7frVYee+RLFxJkDOJp
n5U8FINPP23TMSDZvDZoeBQERdVLmxis0IDNPPYaXardbQyuyXV2RTPnYLvi
xPHP2U52J+3ZA4lfRYWKwXYGddSwKVa8P58BtTHKzCJNkpnneppBr3/I9T4F
C0vJ6HmJNwPadqecxf6+Tb1db7U4d5IYu2JEvTTcz2h28ppe0INU+7heyoKo
n5QV6NF/f2AoIZQFvb6nUS/2V8hiZeHriyM2PQSacJKFl/lgbdtPvVhvJIfx
G6RgfwOIu+XGLk70L8wAWq63P+9gaqfkm5Mr7v44MFMmwJo6NJs+p0c4XZR1
JoyECokNR/UoN5LBGU2om3i+0VymE/fBYkLVGEnYwji4uZ3J/VCpdfCaf8sa
0HXMqDHBM6upZDRVI86n2ITgmYd+08Mp4jyzTViigVNqMT7WhDvUCKla/L7X
BLpGXmeT0UQH+kvACH2pUYl+9QrIJusVuKoExfliAQ/omaEEXWdZtAALjRtR
iPN0F7CLyCviFeK8unk00g9jSfj3v5VGfHE91J+Ev8kFnlk=
                    "], {{397.24569999999994`, 52.252300000000005`}, {
                    368.20269999999994`, 52.252300000000005`}, {
                    368.20269999999994`, 73.5373}, {397.24569999999994`, 
                    73.5373}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxlk3swVFEcx3ckGqEHUpNq5FFRKdNMD8m3l5EalRBr19prNdlr995L6zH+
iPQwFWOmB2kV2hFFykykZFKDRgkZ8ogkeaWmMVIM6dx2Wn/0x51zP+d8f+f3
O7/zPdYU4x2qJxAItpCPH3NsyibPWbNoaPYbdnLzgTre/vlZa8V/HKMmyqRA
hP7slWbvUcC3Mk/jpQ7E2dtHa51zFLg8ZiBJbwjEncJWSdS4Ava9iTfqDETo
u7j6q4mHEnvDmO9nXEXwyCQb5ikh2rVjoC1ehLxTh/dlmjI4TGdEq7+JMHuh
uVt1FIMWkv5JohgvHqxX3upgMF0cN3LfOAiHeJ0Fi+vRpKDCIPCyVc4soril
Jt1SCbY/9b5qfZBF68KRnfXGwfjob1naKGbR0i93HFPN8DYbz7jEwRkm5HQg
XQqRoup3MVisXDEa7mdJwYc/pyELYVP5J/MQCpKog8sXZTE47XQg16iAwmhZ
+/mpWQzsVXoZcxopmLlVv3+4Q6njkNfi/S+rFDpeQI733oX069wZYVMJpe2H
Jly7fyKFSNu06dTF4QgTMAn6RyikHDlhm3aFRuGFjuMCCwoqkl6+gobDq/k1
j2ulqEt629XdLEeukbudSj3Df/WxMtQYul73/SEHUT9KPi3DQGnRrH4hDdpx
LK0zXwbmDQkYojH8bKuNZ6MM5HZbNmWHI4mUVz4u09YbrUDXJVLwmlBo1u62
+uKj1PZvZyhMKjZcc3BmdMy3UyBhdZya9Wtj3xTx17HmfvmgDO68UTgO7a6x
/nkuMqSoyMV95qD5UGGqTg5Bx7uESPdlEUjvJAnvUzouKqFOtqVJdfy3f2PB
IK44RC+IgAlXcKHjWDCIG+bNneDg3HfPrvedRHufPRxG+cCeIG18JYebdXfq
m42CtOtXOfA2mndUjIIJMkOT+vifbBF4md9mDhHEXusmib8JDk+wuMuPNHkP
S3r8LStYFPJx7UJovGAmjWFhReSpPkLwNi1zZJHPL3QG4N97u+g5pL+pLgB/
AIGeoHU=
                    "], {{260.24569999999994`, 52.252300000000005`}, {
                    231.20369999999997`, 52.252300000000005`}, {
                    231.20369999999997`, 73.5373}, {260.24569999999994`, 
                    73.5373}}}]}}}}}, FrameStyle -> Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], Background -> GrayLevel[0.94], Axes -> 
               False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], Frame -> True, FrameTicks -> None, 
               FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Text\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Markov\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Number of tokens: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["11450", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Markov order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->("SequencePredictorFunction[\[Ellipsis]]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellLabel->"Out[4]=",
 CellID->741449068,ExpressionUUID->"4b18fa03-bacb-46e4-81c2-2ac85901653c"]
}, Open  ]],

Cell["\<\
Complete the preceding string with 10 consecutive words (spaces and \
punctuation marks are considered as words):\
\>", "Text",
 CellID->2146690618,ExpressionUUID->"e289acfc-b227-4607-b7dc-33e88438ef28"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spword", "[", 
  RowBox[{"\"\<I\>\"", ",", 
   RowBox[{"\"\<RandomNextElement\>\"", "\[Rule]", "10"}]}], "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->1881586013,ExpressionUUID->"9cec1289-5888-4410-a000-980e3c074bbc"],

Cell[BoxData["\<\" may see if I hatred\"\>"], "Output",
 CellLabel->"Out[5]=",
 CellID->1278220871,ExpressionUUID->"0d19b2b5-77e0-4818-b1c4-9cd80c4b337f"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{960, 949},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"3d3e4bc2-34dc-4440-bee4-753cfea4723d"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[583, 22, 222, 4, 98, "Title",ExpressionUUID->"3894caf4-5037-4ed6-b57a-c15f855cc6b6"],
Cell[CellGroupData[{
Cell[830, 30, 187, 3, 67, "Section",ExpressionUUID->"3ad9457c-e5b3-4a8e-bdee-f29ff6b4d8b2"],
Cell[CellGroupData[{
Cell[1042, 37, 185, 3, 54, "Subsection",ExpressionUUID->"37c50f37-a104-4ba5-bfea-21ce7e6687d7"],
Cell[1230, 42, 347, 7, 58, "Text",ExpressionUUID->"0b38ea4f-3b27-49d3-9162-7098af5102d7"],
Cell[CellGroupData[{
Cell[1602, 53, 207, 4, 30, "Input",ExpressionUUID->"ac5a44be-5570-4ad4-aca8-dfde52ebb472"],
Cell[1812, 59, 1827, 29, 129, "Output",ExpressionUUID->"dbb92afd-c5c9-46f1-80f8-1fcbc5c9d468"]
}, Open  ]],
Cell[3654, 91, 179, 3, 35, "Text",ExpressionUUID->"474bb9d5-e07b-4cc9-b633-a2421ecbc498"],
Cell[CellGroupData[{
Cell[3858, 98, 207, 4, 30, "Input",ExpressionUUID->"20ca7e72-a2d2-4b42-b4fe-104c43e590a4"],
Cell[4068, 104, 190, 3, 34, "Output",ExpressionUUID->"df705068-dc89-4531-b77a-e2c0db8ebaa7"]
}, Open  ]],
Cell[4273, 110, 242, 6, 35, "Text",ExpressionUUID->"1e6ff15a-f850-4b41-bfd7-5866ba9026b5"],
Cell[CellGroupData[{
Cell[4540, 120, 225, 4, 30, "Input",ExpressionUUID->"eda8f463-7509-444b-a3cf-d5bcccc5d5e1"],
Cell[4768, 126, 191, 3, 34, "Output",ExpressionUUID->"a3022ccc-c722-4960-996e-4fb0fd9cb7fa"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5008, 135, 177, 3, 54, "Subsection",ExpressionUUID->"3aa90122-6986-4f43-be27-9d2e62182298"],
Cell[5188, 140, 183, 3, 35, "Text",ExpressionUUID->"d1f2f584-b883-4a17-84e6-9b468e1fa353"],
Cell[CellGroupData[{
Cell[5396, 147, 221, 4, 30, "Input",ExpressionUUID->"d860fb2b-5a19-459b-ba64-d7d6c19dcb3b"],
Cell[5620, 153, 160, 3, 34, "Output",ExpressionUUID->"5cafa0a4-4701-45f3-be21-e01f41555496"]
}, Open  ]],
Cell[5795, 159, 281, 5, 35, "Text",ExpressionUUID->"6c0ebe9e-7002-4d24-bb62-365104d4c1df"],
Cell[CellGroupData[{
Cell[6101, 168, 191, 3, 30, "Input",ExpressionUUID->"9f45b3a0-5958-4a53-ac6f-c4a47c27852b"],
Cell[6295, 173, 192, 3, 34, "Output",ExpressionUUID->"06f3165d-65b5-4087-823a-19f357a9dd91"]
}, Open  ]],
Cell[6502, 179, 310, 6, 35, "Text",ExpressionUUID->"2de434a6-c61a-4f30-a504-0831707455c5"],
Cell[CellGroupData[{
Cell[6837, 189, 258, 5, 30, "Input",ExpressionUUID->"8c868894-921e-4bf6-95f1-2c0e506a119d"],
Cell[7098, 196, 338, 7, 34, "Output",ExpressionUUID->"11ad3af2-a0b3-43ff-b801-19d300810dd6"]
}, Open  ]],
Cell[7451, 206, 237, 6, 35, "Text",ExpressionUUID->"123a88f0-549a-43b0-ac9b-8cf36e8b3e1f"],
Cell[CellGroupData[{
Cell[7713, 216, 380, 9, 30, "Input",ExpressionUUID->"fb43c1e9-817d-4a7f-baca-7d9b91eb9ebe"],
Cell[8096, 227, 188, 3, 34, "Output",ExpressionUUID->"cabefd4e-45a1-49fb-b6d6-eba3b2aa91cb"]
}, Open  ]],
Cell[8299, 233, 379, 8, 58, "Text",ExpressionUUID->"3fbf4bbc-49ce-452f-9af2-b5ae7915fd53"],
Cell[CellGroupData[{
Cell[8703, 245, 413, 10, 30, "Input",ExpressionUUID->"a10c94fe-f5fb-4019-ad71-a28cd8604b07"],
Cell[9119, 257, 410, 8, 34, "Output",ExpressionUUID->"856859f4-a1a8-475c-82db-38eb56ed2f72"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9566, 270, 476, 10, 30, "Input",ExpressionUUID->"a6db4580-72cc-4f3f-bf81-51ea6ed4853f"],
Cell[10045, 282, 193, 3, 34, "Output",ExpressionUUID->"06c7329f-5ffa-411b-9dd4-810d2e74b01f"]
}, Open  ]],
Cell[10253, 288, 287, 7, 35, "Text",ExpressionUUID->"3174a657-809b-444a-9bb1-ad21cf13192a"],
Cell[CellGroupData[{
Cell[10565, 299, 432, 11, 30, "Input",ExpressionUUID->"a537ab76-1416-4408-8a0f-66cb39b7c7c9"],
Cell[11000, 312, 195, 3, 34, "Output",ExpressionUUID->"d4c79381-f0d8-49da-93e2-e4c3987e0416"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11244, 321, 162, 3, 54, "Subsection",ExpressionUUID->"ee5f01f1-9eab-482e-9d39-2cde96652dad"],
Cell[11409, 326, 331, 7, 35, "Text",ExpressionUUID->"8231692c-7584-433e-ace0-f87cb3644377"],
Cell[CellGroupData[{
Cell[11765, 337, 358, 8, 33, "Input",ExpressionUUID->"fd05f16f-3299-4da9-be23-df552ae9ef90"],
Cell[12126, 347, 209, 3, 34, "Output",ExpressionUUID->"97b4b1fb-5526-47f7-9240-e65a408789e0"]
}, Open  ]],
Cell[12350, 353, 172, 3, 35, "Text",ExpressionUUID->"6c2ccad2-6a67-48c2-8627-7d69a0617e76"],
Cell[CellGroupData[{
Cell[12547, 360, 463, 12, 54, "Input",ExpressionUUID->"7ef08601-368f-4593-9017-2d0739e13bf8"],
Cell[13013, 374, 214, 4, 34, "Output",ExpressionUUID->"d046d4ac-8731-44ac-836e-5b18a1a08a5c"]
}, Open  ]],
Cell[13242, 381, 283, 7, 35, "Text",ExpressionUUID->"d7573f58-b989-4336-99ce-ed66845d9e01"],
Cell[CellGroupData[{
Cell[13550, 392, 446, 11, 33, "Input",ExpressionUUID->"164c8c09-97d4-4995-93d1-5c6bf01bc8a7"],
Cell[13999, 405, 184, 3, 34, "Output",ExpressionUUID->"b907ca79-44c5-4c87-9a26-a40f80a9cc8b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14232, 414, 195, 3, 54, "Subsection",ExpressionUUID->"d24901ae-301d-4522-927d-ec7026c74f3e"],
Cell[14430, 419, 458, 9, 58, "Text",ExpressionUUID->"fe4c6ce0-d8d6-453e-b743-fbe60755f1fe"],
Cell[14891, 430, 241, 6, 35, "Text",ExpressionUUID->"d6f1cd6e-2344-4d78-8333-6abba56d0df7"],
Cell[CellGroupData[{
Cell[15157, 440, 353, 9, 30, "Input",ExpressionUUID->"ec2537af-fa9f-4175-b706-1ab677c2f913"],
Cell[15513, 451, 197, 5, 34, "Output",ExpressionUUID->"90783e9e-d055-4982-bbb3-1e298b67a29f"]
}, Open  ]],
Cell[15725, 459, 606, 10, 81, "Text",ExpressionUUID->"ad7a4d90-e6c1-408f-b2f4-0d6c199d1369"],
Cell[16334, 471, 395, 8, 58, "Text",ExpressionUUID->"728038c8-1e79-4962-bb87-131f5c632a07"],
Cell[CellGroupData[{
Cell[16754, 483, 228, 4, 30, "Input",ExpressionUUID->"f24e357c-955d-49a5-801f-bc08a587e224"],
Cell[16985, 489, 179, 3, 34, "Output",ExpressionUUID->"1b4810a9-f883-4265-aaac-399ea52ec658"]
}, Open  ]],
Cell[17179, 495, 414, 8, 58, "Text",ExpressionUUID->"157ee938-f1e3-480e-a046-f8a60f3e33d1"],
Cell[CellGroupData[{
Cell[17618, 507, 252, 5, 30, "Input",ExpressionUUID->"548e95da-3d6c-4722-b612-cb2116041eb2"],
Cell[17873, 514, 156, 3, 34, "Output",ExpressionUUID->"1643ad32-e5e8-49f6-92dd-af7899419291"]
}, Open  ]],
Cell[18044, 520, 498, 9, 81, "Text",ExpressionUUID->"c5e764ab-39f3-425f-90f0-5fc407f0a631"],
Cell[CellGroupData[{
Cell[18567, 533, 501, 14, 30, "Input",ExpressionUUID->"5b5cbd5e-05e8-4a47-a24f-cc4441c1fbe8"],
Cell[19071, 549, 245, 5, 34, "Output",ExpressionUUID->"d7ff0e0f-0432-4d0e-8756-61d47091f735"]
}, Open  ]],
Cell[19331, 557, 245, 6, 35, "Text",ExpressionUUID->"4e136f91-6bcb-4788-ac8e-324c88bf842b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19613, 568, 170, 3, 54, "Subsection",ExpressionUUID->"6b11201a-f3a6-49d4-b4e6-7ee787e023ae"],
Cell[19786, 573, 658, 14, 58, "Text",ExpressionUUID->"ea55a498-b280-4ec7-b549-2efc2ee6edb1"],
Cell[CellGroupData[{
Cell[20469, 591, 299, 6, 30, "Input",ExpressionUUID->"21518b62-02e4-4741-b495-5c082e75e2db"],
Cell[20771, 599, 189, 3, 34, "Output",ExpressionUUID->"5309c484-b60a-401f-a94e-556436936764"]
}, Open  ]],
Cell[20975, 605, 187, 3, 35, "Text",ExpressionUUID->"b6e52cf9-a547-4972-8945-89b623a254a9"],
Cell[21165, 610, 554, 9, 81, "Text",ExpressionUUID->"815e755f-0859-404d-8837-dfe0fae69e8b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21768, 625, 155, 3, 67, "Section",ExpressionUUID->"5f11be89-dc8d-4e6e-84e2-fc08d0ea3482"],
Cell[21926, 630, 323, 7, 35, "Text",ExpressionUUID->"41c50f9f-3bc6-4bd0-9256-5c9ec25cf106"],
Cell[CellGroupData[{
Cell[22274, 641, 156, 3, 54, "Subsection",ExpressionUUID->"150b7fa0-267e-4788-a6d1-80fa6ebbfc32"],
Cell[22433, 646, 442, 9, 58, "Text",ExpressionUUID->"c6816cc1-bf58-4b3b-82d6-7f7602edd49f"],
Cell[22878, 657, 539, 8, 104, "Text",ExpressionUUID->"b3f8610e-6e64-4739-ba5b-c3ad3d89cf59"],
Cell[23420, 667, 195, 3, 35, "Text",ExpressionUUID->"a5d41192-ee45-408a-b6ef-e766787ee123"],
Cell[23618, 672, 574, 9, 104, "Text",ExpressionUUID->"dd2d0d03-13e3-4efb-942a-08ea7cc107a2"],
Cell[24195, 683, 154, 3, 35, "Text",ExpressionUUID->"ba52d3c8-ddfd-4ba0-b145-5b104722d1ad"],
Cell[24352, 688, 675, 10, 140, "Output",ExpressionUUID->"9abaaf8b-b3d9-4265-a4b0-1a9faeaa16dd"],
Cell[CellGroupData[{
Cell[25052, 702, 156, 3, 45, "Subsubsection",ExpressionUUID->"075af583-6c91-4269-bec3-71c41fa11f46"],
Cell[25211, 707, 213, 4, 35, "Text",ExpressionUUID->"20d96a17-a638-4efd-bbcd-bfcc0c9c9ea1"],
Cell[25427, 713, 170, 3, 32, "Item",ExpressionUUID->"8ac58c4f-ca82-4690-86c8-8d107d4efb2b"],
Cell[25600, 718, 240, 6, 32, "Item",ExpressionUUID->"4fc68744-8c18-4ca9-a493-814b9aad3a36"],
Cell[25843, 726, 178, 3, 32, "Item",ExpressionUUID->"d7c150fa-fbbd-40a2-a607-a1fc5dd4c0c8"]
}, Closed]],
Cell[CellGroupData[{
Cell[26058, 734, 157, 3, 37, "Subsubsection",ExpressionUUID->"b8d09e27-37ec-4178-a477-9223e8f28743"],
Cell[26218, 739, 238, 4, 35, "Text",ExpressionUUID->"0c02e3e8-cac2-4b38-9091-062a312e9cf8"],
Cell[26459, 745, 207, 4, 32, "Item",ExpressionUUID->"5ffb391a-fe6e-410a-ba15-328197e9c289"],
Cell[26669, 751, 154, 3, 32, "Item",ExpressionUUID->"20ae750e-7063-489d-ba11-462dbb43af93"],
Cell[26826, 756, 153, 3, 32, "Item",ExpressionUUID->"d4cd6236-6685-424a-b92f-aae6adb59634"],
Cell[26982, 761, 157, 3, 32, "Item",ExpressionUUID->"e83007cc-f8b8-4e38-bba3-ceef5a5f2692"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27188, 770, 153, 3, 54, "Subsection",ExpressionUUID->"bc42c7a9-5566-40d3-a132-b8f30a15b91d"],
Cell[27344, 775, 685, 12, 104, "Text",ExpressionUUID->"63f32334-6526-4769-a18c-50d6f2007c08"],
Cell[CellGroupData[{
Cell[28054, 791, 240, 4, 30, "Input",ExpressionUUID->"4cd73264-ef9f-474d-a3da-6725d63223be"],
Cell[28297, 797, 7911, 196, 80, "Output",ExpressionUUID->"76b0649f-7a8d-42ca-9c6f-239fda11d749"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36245, 998, 280, 6, 30, "Input",ExpressionUUID->"d4d0719e-ac92-4474-9b33-5c9b0ec7b11a"],
Cell[36528, 1006, 186, 4, 34, "Output",ExpressionUUID->"0c936447-c8fe-4b35-964b-fd8d2f9feef2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36751, 1015, 282, 6, 30, "Input",ExpressionUUID->"7ac60696-bf15-4bbf-b3ef-5d874df9d24c"],
Cell[37036, 1023, 220, 5, 34, "Output",ExpressionUUID->"71362cfc-6e27-44ee-aa06-3c85dac41286"]
}, Open  ]],
Cell[37271, 1031, 230, 4, 35, "Text",ExpressionUUID->"2c967ecf-d352-4485-8342-8b512e07ff48"],
Cell[37504, 1037, 754, 16, 69, "Output",ExpressionUUID->"d7624e3a-08ab-4a9a-bbd2-d064fc04f041"],
Cell[38261, 1055, 786, 17, 69, "Output",ExpressionUUID->"e00c75b1-6817-4f07-b0a7-e37a2e58feaa"],
Cell[CellGroupData[{
Cell[39072, 1076, 156, 3, 45, "Subsubsection",ExpressionUUID->"6f136017-581a-4e7d-a0b6-86acff2fdddc"],
Cell[39231, 1081, 211, 4, 35, "Text",ExpressionUUID->"a0bbbd32-e228-4389-8560-eec6dd8a126b"],
Cell[39445, 1087, 225, 4, 32, "Item",ExpressionUUID->"191d4549-19d1-49f6-b92a-0c01a8f3430f"],
Cell[39673, 1093, 238, 4, 32, "Item",ExpressionUUID->"89de83a8-0f30-47dc-8903-6462671887a4"],
Cell[39914, 1099, 246, 4, 32, "Item",ExpressionUUID->"c2ee2773-c6d3-40bb-a310-57e1696f642f"],
Cell[40163, 1105, 210, 3, 32, "Item",ExpressionUUID->"a28137dd-1e53-4d16-924b-fe58eaa6fb5a"],
Cell[40376, 1110, 177, 3, 32, "Item",ExpressionUUID->"bb783001-3a7f-47fd-9535-90db6fcf81e2"]
}, Closed]],
Cell[CellGroupData[{
Cell[40590, 1118, 156, 3, 37, "Subsubsection",ExpressionUUID->"1792dcf6-9018-4504-a833-97424621ee87"],
Cell[40749, 1123, 236, 4, 35, "Text",ExpressionUUID->"08168ac9-01ac-433c-90df-74de33c6f438"],
Cell[40988, 1129, 154, 3, 32, "Item",ExpressionUUID->"b43ee2e0-61aa-4987-a23d-02d8262a2165"],
Cell[41145, 1134, 156, 3, 32, "Item",ExpressionUUID->"ff23f6dc-6771-4c8a-885a-c5f8cffe0054"],
Cell[41304, 1139, 151, 3, 32, "Item",ExpressionUUID->"b9f6bd6d-d336-495f-a02c-be0994929ed5"],
Cell[41458, 1144, 150, 3, 32, "Item",ExpressionUUID->"a50ea82e-eb6d-4f6c-aee8-ae418ed78ecb"],
Cell[41611, 1149, 154, 3, 32, "Item",ExpressionUUID->"50aea41d-72f9-49a7-ad31-571f182d925d"],
Cell[41768, 1154, 152, 3, 32, "Item",ExpressionUUID->"5b0cb389-4e24-47af-b5d7-1dca80ce681d"],
Cell[41923, 1159, 153, 3, 32, "Item",ExpressionUUID->"4f6358be-f6dd-4d0d-aeba-3a382d2a7177"],
Cell[42079, 1164, 146, 3, 32, "Item",ExpressionUUID->"4b4620e6-12ae-436a-aeac-0ccd8a28226c"],
Cell[42228, 1169, 152, 3, 32, "Item",ExpressionUUID->"716bb08d-46e9-4637-aeee-e45d55934a06"],
Cell[42383, 1174, 150, 3, 32, "Item",ExpressionUUID->"05078e29-6456-45eb-9ffa-1c2fa0816f42"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42582, 1183, 184, 3, 54, "Subsection",ExpressionUUID->"9404b1a0-e6b3-47b5-8456-fabb69f10bee"],
Cell[42769, 1188, 808, 14, 150, "Text",ExpressionUUID->"cb6985b1-6ff9-4de7-bc53-553bf42eb76d"],
Cell[CellGroupData[{
Cell[43602, 1206, 193, 3, 45, "Subsubsection",ExpressionUUID->"2f1f1a82-9219-4aeb-a77a-a0f1a504488c"],
Cell[43798, 1211, 387, 12, 40, "Text",ExpressionUUID->"a9ac614d-30a5-4fcf-b9b3-fb12927a32bf",
 CellID->1603154666],
Cell[44188, 1225, 298, 8, 30, "Input",ExpressionUUID->"8e38da69-ff90-4413-9834-b88c4f5b5092",
 CellID->1446587299],
Cell[44489, 1235, 132, 1, 35, "Text",ExpressionUUID->"1f0bd9d2-3ac5-4d18-953d-d2df55cdd86a",
 CellID->1327236851],
Cell[CellGroupData[{
Cell[44646, 1240, 219, 5, 30, "Input",ExpressionUUID->"b17f4db8-b3d0-43e2-848f-3145d5086baa",
 CellID->361313456],
Cell[44868, 1247, 20042, 370, 62, "Output",ExpressionUUID->"8440793e-d4d9-4040-84a4-5a4461e2228f",
 CellID->1573551892]
}, Open  ]],
Cell[64925, 1620, 132, 1, 35, "Text",ExpressionUUID->"2de7c40c-f109-480d-8c83-56b455a434f6",
 CellID->973282071],
Cell[CellGroupData[{
Cell[65082, 1625, 271, 6, 30, "Input",ExpressionUUID->"daafc5f0-2111-4dac-9d48-513d6a38c44c",
 CellID->430347037],
Cell[65356, 1633, 176, 3, 34, "Output",ExpressionUUID->"49cf8bb8-fdd8-47fd-bedc-7f5e6d345d23",
 CellID->1150286512]
}, Open  ]],
Cell[65547, 1639, 207, 4, 35, "Text",ExpressionUUID->"317b9859-6987-4d8b-8dfd-1f0a8d6c27cd",
 CellID->1204346087],
Cell[CellGroupData[{
Cell[65779, 1647, 315, 8, 30, "Input",ExpressionUUID->"0c9fb804-7de0-42f0-b797-77ae5ad7f63c",
 CellID->398119440],
Cell[66097, 1657, 20044, 370, 62, "Output",ExpressionUUID->"4b18fa03-bacb-46e4-81c2-2ac85901653c",
 CellID->741449068]
}, Open  ]],
Cell[86156, 2030, 213, 4, 35, "Text",ExpressionUUID->"e289acfc-b227-4607-b7dc-33e88438ef28",
 CellID->2146690618],
Cell[CellGroupData[{
Cell[86394, 2038, 244, 5, 30, "Input",ExpressionUUID->"9cec1289-5888-4410-a000-980e3c074bbc",
 CellID->1881586013],
Cell[86641, 2045, 154, 2, 34, "Output",ExpressionUUID->"0d19b2b5-77e0-4818-b1c4-9cd80c4b337f",
 CellID->1278220871]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

